#include "AboutDialog.h"
#include "IconHelper.h"
#include "Common.h"

#include <QPainter>
#include <qmath.h>

AboutDialog::AboutDialog(QWidget *parent)
    : FlatDropWidget(parent)
{
    this->setWindowFlags(Qt::FramelessWindowHint | Qt::Tool);
    this->setFixedSize(ABOUT_DIALOG_WIDTH, ABOUT_DIALOG_HEIGHT);
    this->initUI();
}

void AboutDialog::initUI()
{
    QPalette palette = this->palette();
    QFont ft;

    setAutoFillBackground(true);
    palette.setColor(QPalette::Background, QColor("#FFFFFF"));
    this->setPalette(palette);

    m_pTitleBar = new TitleBar(this);
    m_pTitleBar->resize(ABOUT_DIALOG_WIDTH, TITLEBAR_HEIGHT);
    m_pTitleBar->setBackgroundColor("#E4E7EA");
    m_pTitleBar->getMinimizeBtn()->setVisible(false);
    m_pTitleBar->getMenuBtn()->setVisible(false);
    m_pTitleBar->getReturnBtn()->setVisible(false);
    m_pTitleBar->setLogoLabel(QString("关于"));
//    m_pTitleBar->hideLogo();

    m_pLogoLabel = new QLabel(this);
    QPixmap pixmap(":/images/logo/kysec_logo/64.png");
    m_pLogoLabel->setPixmap(pixmap);
    m_pLogoLabel->setFixedSize(64, 64);
    m_pLogoLabel->move(120, 80);

    m_maintanLabel = new QLabel(this);
    m_maintanLabel->setText(QString("麒麟安全管理工具"));
    palette.setColor(QPalette::WindowText, QColor("#121217"));
    ft.setPixelSize(32);
    m_maintanLabel->setPalette(palette);
    m_maintanLabel->setFont(ft);
    m_maintanLabel->setScaledContents(true);
    m_maintanLabel->move(190, 90);

//    m_pInfoLabel = new QLabel(this);
//    m_pInfoLabel->setText(QString("检查应用程序和文件的完整性,保护系统运行环境安全可靠"));
//    palette.setColor(QPalette::WindowText, QColor("#89898F"));
//    ft.setPixelSize(14);
//    m_pInfoLabel->setPalette(palette);
//    m_pInfoLabel->setFont(ft);
//    m_pInfoLabel->setWordWrap(true);
//    m_pInfoLabel->setFixedWidth(320);
//    m_pInfoLabel->setScaledContents(true);
//    m_pInfoLabel->move(160, 120);

    QLabel *m_pEnvLabel = new QLabel(this);
    m_pEnvLabel->setText(QString("运行环境: 银河麒麟操作系统 (V10)"));
    palette.setColor(QPalette::WindowText, QColor("#49494E"));
    ft.setPixelSize(12);
    m_pEnvLabel->setPalette(palette);
    m_pEnvLabel->setFont(ft);
    m_pEnvLabel->setScaledContents(true);
    m_pEnvLabel->move(170, 190);

    QLabel *m_pKernelLabel = new QLabel(this);
    m_pKernelLabel->setText(QString("安全内核 (3.0.0) 以上"));
    palette.setColor(QPalette::WindowText, QColor("#49494E"));
    ft.setPixelSize(12);
    m_pKernelLabel->setPalette(palette);
    m_pKernelLabel->setFont(ft);
    m_pKernelLabel->setScaledContents(true);
    m_pKernelLabel->move(225, 210);

    QLabel *m_pApplyLabel = new QLabel(this);
    m_pApplyLabel->setText(QString("安全动态库 (3.1.2) 以上"));
    palette.setColor(QPalette::WindowText, QColor("#49494E"));
    ft.setPixelSize(12);
    m_pApplyLabel->setPalette(palette);
    m_pApplyLabel->setFont(ft);
    m_pApplyLabel->setScaledContents(true);
    m_pApplyLabel->move(225, 230);

    m_pVersionLabel = new QLabel(this);
    m_pVersionLabel->setText(QString("软件版本: 1.0.7"));
    palette.setColor(QPalette::WindowText, QColor("#49494E"));
    ft.setPixelSize(12);
    m_pVersionLabel->setPalette(palette);
    m_pVersionLabel->setFont(ft);
    m_pVersionLabel->setScaledContents(true);
    m_pVersionLabel->move(170, 260);

    m_pCopyrightLabel = new QLabel(this);
    m_pCopyrightLabel->setText(QString("Copyright(c) kylinos. All Rights Reserved."));
    palette.setColor(QPalette::WindowText, QColor("#49494E"));
    ft.setPixelSize(12);
    m_pCopyrightLabel->setPalette(palette);
    m_pCopyrightLabel->setFont(ft);
    m_pCopyrightLabel->setScaledContents(true);
    m_pCopyrightLabel->move(170, 290);


//    m_pMainLayout = new QVBoxLayout();
//    m_pMainLayout->setSpacing(0);
//    m_pMainLayout->addWidget(m_pTitleBar, 0, Qt::AlignCenter);
//    m_pMainLayout->addSpacing(50);
//    m_pMainLayout->addWidget(m_pLogoLabel, 0, Qt::AlignCenter);
//    m_pMainLayout->addSpacing(20);
//    m_pMainLayout->addWidget(m_maintanLabel, 0, Qt::AlignCenter);
//    m_pMainLayout->addSpacing(16);
//    m_pMainLayout->addWidget(m_pInfoLabel, 0, Qt::AlignCenter);
//    m_pMainLayout->addSpacing(64);
//    m_pMainLayout->addWidget(m_pVersionLabel, 0, Qt::AlignCenter);
//    m_pMainLayout->addSpacing(16);
//    m_pMainLayout->addWidget(m_pCopyrightLabel, 0, Qt::AlignCenter);
//    m_pMainLayout->addSpacing(40);
//    m_pMainLayout->addStretch(0);
//    m_pMainLayout->setContentsMargins(0, 0, 0, 0);

    connect(m_pTitleBar->getCloseBtn(), SIGNAL(clicked()), this, SLOT(close()));
//    this->setLayout(m_pMainLayout);
}

AboutDialog::~AboutDialog()
{
    delete m_pTitleBar;
    delete m_pLogoLabel; //图标
    delete m_maintanLabel;
//    delete m_pInfoLabel; //slogan
    delete m_pVersionLabel; //主程序版本
    delete m_pCopyrightLabel; //版本信息
}
