#include "FilterSelectDialog.h"
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QDebug>
#include <QMouseEvent>
#include "KysecTableModelBase.h"
#include "GlobalDef.h"

FilterSelectDialog::FilterSelectDialog(filter_types type, QWidget *parent)
    : QDialog(parent)
{
    setMouseTracking(true);
    this->setWindowFlags(Qt::FramelessWindowHint|Qt::Popup );
    m_type =type;    
}

void FilterSelectDialog::getFilterItems(QMap<int, bool> &filters)
{
    if (filter_execctrl_type == m_type)
    {
        m_filters[object_program] = m_checks[0]->isChecked();
        m_filters[object_library] = m_checks[1]->isChecked();
        m_filters[object_script] = m_checks[2]->isChecked();
    }

    if (filter_execctrl_status == m_type || filter_kmodprotect_status == m_type)
    {
        m_filters[exectl_status_verified] = m_checks[0]->isChecked();
        m_filters[exectl_status_system] = m_checks[1]->isChecked();
        m_filters[exectl_status_unauth] = m_checks[2]->isChecked();
        m_filters[exectl_status_distort] = m_checks[3]->isChecked();
    }

    if (filter_fileprotect_status == m_type)
    {
        m_filters[filepro_sign_readonly] = m_checks[0]->isChecked();
        m_filters[filepro_sign_none] = m_checks[1]->isChecked();
    }

    filters = m_filters;
}

void FilterSelectDialog::setFilterItems(QMap<int, bool> filters)
{
    m_filters = filters;
    initUI();
}

void FilterSelectDialog::initUI()
{
    setAutoFillBackground(true);
    QPalette palette(this->palette());
    palette.setColor(QPalette::Background, QColor("#FFFFFF"));
    this->setPalette(palette);

    m_pVBoxLayout = new QVBoxLayout();

    initCheckBoxs(m_pVBoxLayout);

//    QFont ft;
//    ft.setPixelSize(14);
//    m_pHBoxLayout = new QHBoxLayout();
//    m_pApplyBtn = new QPushButton(QString("确定"), this);
//    m_pApplyBtn->setFixedSize(36, 18);
//    m_pApplyBtn->setFont(ft);
//    m_pApplyBtn->setObjectName("FilterBtn");
//    connect(m_pApplyBtn, SIGNAL(clicked(bool)), this, SLOT(slot_applyBtnClicked()));
//    m_pCancelBtn = new QPushButton(QString("取消"), this);
//    m_pCancelBtn->setFixedSize(36, 18);
//    m_pCancelBtn->setObjectName("FilterBtn");
//    m_pCancelBtn->setFont(ft);
//    connect(m_pCancelBtn, SIGNAL(clicked(bool)), this, SLOT(slot_cancelBtnClicked()));
////    m_pHBoxLayout->addSpacerItem(new QSpacerItem(40, 20, QSizePolicy::Expanding));
//    m_pHBoxLayout->addWidget(m_pApplyBtn);
//    m_pHBoxLayout->addWidget(m_pCancelBtn);

//    m_pSplitLine = new QFrame(this);
//    m_pSplitLine->setFixedSize(90, 1);
//    m_pSplitLine->setFrameShape(QFrame::HLine);
//    m_pSplitLine->setFrameShadow(QFrame::Sunken);
//    m_pSplitLine->setStyleSheet("border:1px solid #1E90FF");

//    m_pVBoxLayout->addWidget(m_pSplitLine, 0, Qt::AlignHCenter);
//    m_pVBoxLayout->addLayout(m_pHBoxLayout);
    setLayout(m_pVBoxLayout);
}

void FilterSelectDialog::initCheckBoxs(QVBoxLayout *pLayout)
{
    if (NULL == pLayout)
        return;

    if (filter_execctrl_type == m_type)
    {
        QCheckBox* p = new QCheckBox(QString("可执行程序"), this);
        p->setFocusPolicy(Qt::NoFocus);
        p->setChecked(m_filters.value(object_program));
        pLayout->addWidget(p, 0, Qt::AlignLeft);
        m_checks.push_back(p);

        p = new QCheckBox(QString("共享库"), this);
        p->setFocusPolicy(Qt::NoFocus);
        p->setChecked(m_filters.value(object_library));
        pLayout->addWidget(p, 0, Qt::AlignLeft);
        m_checks.push_back(p);

        p = new QCheckBox(QString("可执行脚本"), this);
        p->setFocusPolicy(Qt::NoFocus);
        p->setChecked(m_filters.value(object_script));
        pLayout->addWidget(p, 0, Qt::AlignLeft);
        m_checks.push_back(p);
    }

    if (filter_execctrl_status == m_type || filter_kmodprotect_status == m_type)
    {
        QCheckBox* p = new QCheckBox(QString("已认证"), this);
        p->setFocusPolicy(Qt::NoFocus);
        p->setChecked(m_filters.value(exectl_status_verified));
        pLayout->addWidget(p, 0, Qt::AlignLeft);
        m_checks.push_back(p);

        p = new QCheckBox(QString("系统认证"), this);
        p->setFocusPolicy(Qt::NoFocus);
        p->setChecked(m_filters.value(exectl_status_system));
        pLayout->addWidget(p, 0, Qt::AlignLeft);
        m_checks.push_back(p);

        p = new QCheckBox(QString("未认证"), this);
        p->setFocusPolicy(Qt::NoFocus);
        p->setChecked(m_filters.value(exectl_status_unauth));
        pLayout->addWidget(p, 0, Qt::AlignLeft);
        m_checks.push_back(p);

        p = new QCheckBox(QString("被篡改"), this);
        p->setFocusPolicy(Qt::NoFocus);
        p->setChecked(m_filters.value(exectl_status_distort));
        pLayout->addWidget(p, 0, Qt::AlignLeft);
        m_checks.push_back(p);
    }

    if (filter_fileprotect_status == m_type)
    {
        QCheckBox* p = new QCheckBox(QString("受保护"), this);
        p->setFocusPolicy(Qt::NoFocus);
        p->setChecked(m_filters.value(filepro_sign_readonly));
        pLayout->addWidget(p, 0, Qt::AlignLeft);
        m_checks.push_back(p);

        p = new QCheckBox(QString("被篡改"), this);
        p->setFocusPolicy(Qt::NoFocus);
        p->setChecked(m_filters.value(filepro_sign_none));
        pLayout->addWidget(p, 0, Qt::AlignLeft);
        m_checks.push_back(p);
    }
}

void FilterSelectDialog::mousePressEvent(QMouseEvent *event)
{

    if (this->rect().contains(event->pos()))
    {
        ;
    }
    else
    {
        done(1);
    }
}

void FilterSelectDialog::slot_applyBtnClicked()
{
    done(1);
}

void FilterSelectDialog::slot_cancelBtnClicked()
{
    this->close();
}
