#include "KysecConfigureDlg.h"
#include <QtWidgets/QTableView>
#include <QtWidgets/QTableWidget>
#include "IconHelper.h"
#include "Common.h"

#include <QDebug>

KysecConfigureDlg::KysecConfigureDlg(QWidget *parent)
    :    QDialog(parent)
{
    setWindowFlags(Qt::FramelessWindowHint);
    initUI();
    initConnections();
}

KysecConfigureDlg::~KysecConfigureDlg()
{

}

void KysecConfigureDlg::slot_showDialog()
{
    m_pExecCtrlManage->refresh();
    m_pFileProtectManage->refresh();
    m_pKmodProtectManage->refresh();
    m_pTabWidget->setCurrentIndex(0);
    slot_tabChanged(0);

    setVisible(true);
}

void KysecConfigureDlg::slot_tabChanged(int index)
{
    if (index == 0)
    {
        m_pExecCtrlManage->refresh();
    }
    else if (index == 1)
    {
        m_pFileProtectManage->refresh();
    }
    else
    {
        m_pKmodProtectManage->refresh();
    }
}

void KysecConfigureDlg::initUI()
{    
    resize(WINDOW_WIDTH, WINDOW_HEIGHT);

    setAutoFillBackground(true);
    QPalette palette = this->palette();
    palette.setColor(QPalette::Background, QColor("#FFFFFF"));
    this->setPalette(palette);

    m_pTitleBar = new TitleBar(this);
    m_pTitleBar->setBackgroundColor("#E4E7EA");
//    m_pTitleBar->getMinimizeBtn()->setVisible(false);
    m_pTitleBar->getMenuBtn()->setVisible(false);
//    m_pTitleBar->getCloseBtn()->setVisible(false);
    m_pTitleBar->setLogoLabel(QString("麒麟安全管理工具 - 安全配置"));

    m_pExecCtrlManage = new KysecDataManage(kysec_exectrl, this);
    m_pFileProtectManage = new KysecDataManage(kysec_filepro, this);
    m_pKmodProtectManage = new KysecDataManage(kysec_kmodpro, this);

    m_pTabWidget = new QTabWidget(this);

    m_pTabWidget->addTab(m_pExecCtrlManage, QString("执行控制"));
    m_pTabWidget->addTab(m_pFileProtectManage, QString("文件保护"));
    m_pTabWidget->addTab(m_pKmodProtectManage, QString("内核模块保护"));

    m_pLayout = new QHBoxLayout();
    m_pLayout->addWidget(m_pTabWidget);
    m_pLayout->setContentsMargins(20, 0, 20, 0);

    m_pMainLayout = new QVBoxLayout();
    m_pMainLayout->setSpacing(0);
    m_pMainLayout->addWidget(m_pTitleBar);
//    m_pMainLayout->addSpacing(30);
    m_pMainLayout->addSpacing(10);
    m_pMainLayout->addLayout(m_pLayout);

    m_pMainLayout->setContentsMargins(0, 0, 0, 15);
    setLayout(m_pMainLayout);
}

void KysecConfigureDlg::initConnections()
{
    connect(m_pTitleBar->getReturnBtn(), SIGNAL(clicked(bool)), this, SIGNAL(signal_returnBtnClicked()));
    connect(m_pTitleBar->getMinimizeBtn(), SIGNAL(clicked(bool)), this, SIGNAL(signal_minimizeBtnClicked()));
    connect(m_pTitleBar->getCloseBtn(), SIGNAL(clicked(bool)), this, SIGNAL(signal_closeBtnClicked()));
    connect(m_pTabWidget, SIGNAL(currentChanged(int)), this, SLOT(slot_tabChanged(int)));    
}
