#include "KysecDataManage.h"
#include "IconHelper.h"
#include "KysecExecCtrlTableModel.h"
#include "KysecFileProtectTableModel.h"
#include "KysecKModProtectTableModel.h"
#include "KysecFileDialog.h"
#include "ProcessAddWaitingDialog.h"
#include "ProcessUpdateWaitingDialog.h"
#include "ProcessDeleteWaitingDialog.h"
#include "GlobalHelper.h"
#include "GlobalDef.h"
#include "KysecMessageBox.h"
#include "kysec/status.h"
#include "FilterSelectDialog.h"

#include <QtWidgets/QHeaderView>
#include <QtWidgets/QScrollBar>
#include <QtWidgets/QMessageBox>
#include <QDebug>

KysecDataManage::KysecDataManage(e_kysec_type type, QWidget *parent)
    : QWidget(parent), m_type(type)
{
    m_bUnloadProtect = true;
    initUI();
    initConnection();
}

KysecDataManage::~KysecDataManage()
{

}

void KysecDataManage::refresh()
{    
    m_pSearchEdit->clear();
    m_pKysecTableModel->refreshData();
    updateStatisticsLabel();
}

bool KysecDataManage::eventFilter(QObject *watched, QEvent *event)
{
    if (!g_bAdmPrivilege)
        return QWidget::eventFilter(watched, event);

    if (NULL != m_pAddBtn && watched == m_pAddBtn)
    {
        if (event->type() == QEvent::Enter)
        {
            m_pAddBtn->setIcon(QIcon(":/images/image/icon_add_blue.png"));
        }
        else if (event->type() == QEvent::Leave)
        {
            m_pAddBtn->setIcon(QIcon(":/images/image/icon_add.png"));
        }
    }

    if (NULL != m_pDeleteBtn && watched == m_pDeleteBtn)
    {
        if (event->type() == QEvent::Enter)
        {
            if (m_pKysecTableModel->getCheckedCount() > 0)
                m_pDeleteBtn->setIcon(QIcon(":/images/image/icon_delete_blue.png"));
            else
                m_pDeleteBtn->setIcon(QIcon(":/images/image/icon_delete_gray.png"));
        }
        else if (event->type() == QEvent::Leave)
        {
            if (m_pKysecTableModel->getCheckedCount() > 0)
                m_pDeleteBtn->setIcon(QIcon(":/images/image/icon_delete.png"));
            else
                m_pDeleteBtn->setIcon(QIcon(":/images/image/icon_delete_gray.png"));
        }
    }

    if (NULL != m_pUpdateBtn && watched == m_pUpdateBtn)
    {
        if (event->type() == QEvent::Enter)
        {
            if (m_pKysecTableModel->getCheckedCount() > 0)
                m_pUpdateBtn->setIcon(QIcon(":/images/image/icon_update_blue.png"));
            else
                m_pUpdateBtn->setIcon(QIcon(":/images/image/icon_update_gray.png"));
        }
        else if (event->type() == QEvent::Leave)
        {
            if (m_pKysecTableModel->getCheckedCount() > 0)
                m_pUpdateBtn->setIcon(QIcon(":/images/image/icon_update.png"));
            else
                m_pUpdateBtn->setIcon(QIcon(":/images/image/icon_update_gray.png"));
        }
    }

    return QWidget::eventFilter(watched, event);
}

void KysecDataManage::initUI()
{
    QPalette palette = this->palette();
    QFont font;

    palette.setColor(QPalette::WindowText, QColor("#696969"));
    font.setPixelSize(12);

    QLabel *m_pStatusLabel = new QLabel(this);
    m_pStatusLabel = new QLabel(this);
    m_pStatusLabel->setFont(font);
    m_pStatusLabel->setPalette(palette);
    m_pStatusLabel->setText("当前模式： 记录模式");
    m_pStatusLabel->move(700, 100);
    m_pStatusLabel->raise();

    m_pRefreshLayout = new QHBoxLayout();
    m_pContentLabel = new QLabel(this);
    m_pContentLabel->setFont(font);
    m_pContentLabel->setPalette(palette);
    if (m_type == kysec_exectrl)
        //m_pContentLabel->setText(QString("禁止外来文件（木马病毒或未知）和被篡改的系统文件运行，杜绝可能造成的侵害"));
        m_pContentLabel->setText(QString("检查应用程序的完整性，保护执行环境安全"));
    else if (m_type == kysec_filepro)
        //m_pContentLabel->setText(QString("保护系统关键文件不被篡改、删除，保证关键数据的完整性"));
        m_pContentLabel->setText(QString("保护关键文件数据，防止恶意篡改、删除"));
    else
//        m_pContentLabel->setText(QString("对系统内核模块进行控制，经过验证的内核模块才允许加载，特定内核模块禁止卸载"));
        m_pContentLabel->setText(QString("管控内核驱动模块，阻止非法加载、卸载"));
/*add by yss*/
    m_pRefreshBtn = new QPushButton(this);
    m_pRefreshBtn->setObjectName("RefreshBtn");
    m_pRefreshBtn->setText("刷新");
    m_pRefreshBtn->setFixedSize(75,27);
    m_pRefreshBtn->setFocus();
    if (m_type == kysec_exectrl)
    {
	    m_pRefreshBtn->show();
    }
    else if(m_type == kysec_filepro)
    {
	    m_pRefreshBtn->hide();
    }
    else
    {
	    m_pRefreshBtn->show();
    }
    m_pRefreshLayout->addWidget(m_pContentLabel);
    m_pRefreshLayout->addWidget(m_pRefreshBtn);

/*add by yss end*/
    m_pSearchLayout = new QHBoxLayout();
    m_pSearchEdit = new QLineEdit(this);
    m_pSearchEdit->setPlaceholderText("请输入搜索内容");
//    m_pSearchEdit->setClearButtonEnabled(true);

    m_pClearAction = new QAction(QIcon(":/images/image/clear_16.png"), "", m_pSearchEdit);
    m_pSearchEdit->addAction(m_pClearAction, QLineEdit::TrailingPosition);
    m_pClearAction->setVisible(false);

    m_pSearchBtn = new QPushButton(this);
    m_pSearchBtn->setObjectName("MenuBtn");
    m_pSearchBtn->setToolTip(QString("搜索"));
    m_pSearchBtn->setIcon(QIcon(":/images/image/search_icon.png"));
    m_pSearchBtn->setFocus();
    m_pSearchBtn->setShortcut(QKeySequence::InsertParagraphSeparator);
    m_pSearchBtn->setShortcut(Qt::Key_Enter);
    m_pSearchBtn->setShortcut(Qt::Key_Return);

    m_pSearchLayout->addWidget(m_pSearchBtn, 0, Qt::AlignVCenter);
    m_pSearchLayout->addWidget(m_pSearchEdit, 0, Qt::AlignVCenter);
    m_pSearchLayout->setSpacing(0);
    m_pSearchLayout->setContentsMargins(12, 0, 12, 0);

    m_pSearchWidget = new QWidget(this);
    m_pSearchWidget->setLayout(m_pSearchLayout);
    m_pSearchWidget->setObjectName("SearchWidget");
    m_pSearchWidget->setFixedSize(480, 36);
    m_pAddBtn = new QToolButton(this);
    m_pAddBtn->setText(QString("添加"));
    m_pAddBtn->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
    if (g_bAdmPrivilege)
        m_pAddBtn->setIcon(QIcon(":/images/image/icon_add.png"));
    else
        m_pAddBtn->setIcon(QIcon(":/images/image/icon_add_gray.png"));
    m_pAddBtn->setEnabled(g_bAdmPrivilege);
    m_pAddBtn->setIconSize(QSize(14, 14));
    palette.setColor(QPalette::WindowText, QColor("#121217"));
    font.setPixelSize(14);
    m_pAddBtn->setPalette(palette);
    m_pAddBtn->setFont(font);
    m_pAddBtn->setObjectName("DataManageToolBtn");
    m_pAddBtn->installEventFilter(this);

    m_pUpdateBtn = new QToolButton(this);
    m_pUpdateBtn->setText(QString("更新"));
    m_pUpdateBtn->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
    m_pUpdateBtn->setIcon(QIcon(":/images/image/icon_update_gray.png"));
    m_pUpdateBtn->setIconSize(QSize(14, 14));
    palette.setColor(QPalette::WindowText, QColor("#E4E7EA"));
    font.setPixelSize(14);
    m_pUpdateBtn->setPalette(palette);
    m_pUpdateBtn->setFont(font);
    m_pUpdateBtn->setEnabled(false);
    m_pUpdateBtn->setObjectName("DataManageToolBtn");
    m_pUpdateBtn->installEventFilter(this);
    if (m_type == kysec_filepro)
        m_pUpdateBtn->setVisible(false);

    m_pDeleteBtn = new QToolButton(this);
    if (m_type == kysec_filepro)
        m_pDeleteBtn->setText(QString("解除保护"));
    else
        m_pDeleteBtn->setText(QString("解除认证"));
    m_pDeleteBtn->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
    m_pDeleteBtn->setIcon(QIcon(":/images/image/icon_delete_gray.png"));
    m_pDeleteBtn->setIconSize(QSize(14, 14));
    palette.setColor(QPalette::WindowText, QColor("#E4E7EA"));
    font.setPixelSize(14);
    m_pDeleteBtn->setPalette(palette);
    m_pDeleteBtn->setFont(font);
    m_pDeleteBtn->setEnabled(false);
    m_pDeleteBtn->setObjectName("DataManageToolBtn");
    m_pDeleteBtn->installEventFilter(this);

    m_pFuncLayout = new QHBoxLayout();
    m_pFuncLayout->addWidget(m_pSearchWidget);
    m_pFuncLayout->addStretch(5);
    m_pFuncLayout->addWidget(m_pAddBtn);
    m_pFuncLayout->addWidget(m_pUpdateBtn);
    m_pFuncLayout->addWidget(m_pDeleteBtn);
    m_pFuncLayout->setSpacing(20);
    m_pFuncLayout->setContentsMargins(0, 0, 0, 0);

    m_pTableView = new KysecTableView(this);
    m_pCheckBoxHeaderView = new CheckBoxHeaderView(Qt::Horizontal, m_pTableView);
    m_pTableView->setHorizontalHeader(m_pCheckBoxHeaderView);

    if (m_type == kysec_exectrl)
        m_pKysecTableModel = new KysecExecCtrlTableModel(this);
    else if (m_type == kysec_filepro)
        m_pKysecTableModel = new KysecFileProtectTableModel(this);
    else
        m_pKysecTableModel = new KysecKModProtectTableModel(this);

    m_pTableView->setModel(m_pKysecTableModel);
    m_pTableView->setKysecModel(m_pKysecTableModel);

    if (m_type == kysec_filepro || m_type == kysec_kmodpro)
        m_pTableView->hideColumn(2);

    if (m_type == kysec_filepro)
    {
        m_pTableView->hideColumn(3);
    }

    if (m_type == kysec_kmodpro && m_bUnloadProtect)
    {
//        m_pTableView->setItemDelegateForColumn(2, new SwitchButtonItemDelegate(m_pTableView, this));
        m_pTableView->showColumn(2);
    }
    m_pKysecItemDelegate = new KysecItemDelegate(m_type, m_pKysecTableModel, m_pTableView);
    m_pTableView->setItemDelegate(m_pKysecItemDelegate);

    m_pTableView->setWordWrap(false);
    m_pTableView->setFocusPolicy(Qt::NoFocus);
    m_pTableView->setShowGrid(false);
    m_pTableView->verticalHeader()->setVisible(false);
    m_pTableView->horizontalHeader()->setHighlightSections(false);
    m_pTableView->setSelectionMode(QAbstractItemView::NoSelection);
    m_pTableView->setSelectionBehavior(QAbstractItemView::SelectRows);

    if (m_type == kysec_exectrl)
    {
        m_pTableView->setColumnWidth(0, 90);
        m_pTableView->setColumnWidth(1, 540);
        m_pTableView->setColumnWidth(2, 120);
    }

    if (m_type == kysec_filepro)
    {
        m_pTableView->setColumnWidth(0, 90);
        m_pTableView->setColumnWidth(1, 660);
    }

    if (m_type == kysec_kmodpro)
    {
        if (m_bUnloadProtect)
        {
            m_pTableView->setColumnWidth(0, 90);
            m_pTableView->setColumnWidth(1, 540);
            m_pTableView->setColumnWidth(2, 120);
        }
        else
        {
            m_pTableView->setColumnWidth(0, 90);
            m_pTableView->setColumnWidth(1, 660);
            m_pTableView->setColumnWidth(2, 0);
        }
    }

    m_pTableView->horizontalHeader()->setStretchLastSection(true);
    m_pTableView->horizontalHeader()->setMinimumHeight(34);
    m_pTableView->verticalHeader()->setDefaultSectionSize(34);
//    m_pTableView->setSortingEnabled(true);
    m_pTableView->horizontalHeader()->setSortIndicatorShown(false);
    m_pKysecTableModel->refreshData();

    font.setPixelSize(12);
    m_pStatisticsLabel = new QLabel(this);
    m_pStatisticsLabel->setFont(font);
    m_pStatisticsLabel->setText(QString("<font color = #696969 >共 %1 行记录，被篡改 </font>").arg("1024")
                                + QString("<font color = #FF0000>%1</font>").arg("256")
                                + QString("<font color = #696969 >%1</font>").arg(" 行"));

    updateStatisticsLabel();

    m_pMainLayout = new QVBoxLayout();
    m_pMainLayout->addLayout(m_pRefreshLayout);
    //m_pMainLayout->addWidget(m_pContentLabel, 0, Qt::AlignLeft);
    m_pMainLayout->addSpacing(10);
    m_pMainLayout->addLayout(m_pFuncLayout);
    m_pMainLayout->addWidget(m_pTableView);
    m_pMainLayout->addWidget(m_pStatisticsLabel, 0, Qt::AlignLeft);
    m_pMainLayout->setContentsMargins(0, 5, 0, 0);

    m_pSearchEdit->setObjectName("SearchEdit");

    setLayout(m_pMainLayout);
}

void KysecDataManage::initConnection()
{
    connect(m_pSearchBtn, SIGNAL(clicked(bool)), this, SLOT(slot_searchBtnClicked()));
    connect(m_pRefreshBtn,SIGNAL(clicked(bool)),this,SLOT(slot_refreshBtnClicked()));
    connect(m_pAddBtn, SIGNAL(clicked(bool)), this, SLOT(slot_addBtnClicked()));
    connect(m_pUpdateBtn, SIGNAL(clicked(bool)), this, SLOT(slot_updateBtnClicked()));
    connect(m_pDeleteBtn, SIGNAL(clicked(bool)), this, SLOT(slot_deleteBtnClicked()));

    connect(m_pTableView, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(slot_doubleClicked(QModelIndex)));
    connect(m_pTableView, SIGNAL(clicked(QModelIndex)), this, SLOT(slot_singleClicked(QModelIndex)));
    connect(m_pTableView, SIGNAL(entered(QModelIndex)), this, SLOT(slot_entered(QModelIndex)));
    connect(m_pKysecTableModel, SIGNAL(signal_checkedChanged(int)), this, SLOT(slot_checkedChanged(int)));
    connect(m_pKysecTableModel, SIGNAL(signal_updateKoStatusFailed(int)), this, SLOT(slot_updateKoStatusFailed(int)));

    connect(m_pTableView, SIGNAL(signal_index_hovered(QModelIndex)), m_pKysecItemDelegate, SLOT(slot_hover_index_changed(QModelIndex)));

//    connect(m_pTableView->horizontalHeader(), SIGNAL(sectionClicked(int)), this, SLOT(slot_headerViewSectionClicked(int)));
    connect(m_pCheckBoxHeaderView, SIGNAL(signal_clickedSection(int)), this, SLOT(slot_headerViewSectionClicked(int)));

    connect(m_pKysecTableModel, SIGNAL(signal_checkedStateChanged(int)), m_pCheckBoxHeaderView, SLOT(slot_stateChanged(int)));
    connect(m_pCheckBoxHeaderView, SIGNAL(signal_stateChanged(int)), m_pKysecTableModel, SLOT(slot_checkedStateChanged(int)));

    connect(m_pClearAction, SIGNAL(triggered(bool)), this, SLOT(slot_clear_search_edit()));
    connect(m_pSearchEdit, SIGNAL(textChanged(QString)), this, SLOT(slot_search_edit_text_changed(QString)));
}

bool KysecDataManage::checkFuncStatus()
{
    int ret = -1;
    if (m_type == kysec_exectrl)
        ret = kysec_get_func_status(FUNC_EXECTL);
    else if (m_type == kysec_filepro)
        ret = kysec_get_func_status(FUNC_FPRO);
    else
        ret = kysec_get_func_status(FUNC_KMOD);

    if (ret != 1)
        return false;
    else
        return true;
}

void KysecDataManage::execCtrlFilter(int index)
{
    if (index < 2)
        return;

    QPoint globalP(m_pTableView->mapToGlobal(QPoint(0, 0)));
    if (index == 2)
    {
        QMap<int, bool> filters;
        m_pKysecTableModel->getTypeFilters(filters);

        FilterSelectDialog* p = new FilterSelectDialog(filter_execctrl_type, this);
        p->setFilterItems(filters);
        p->resize(90, 120);
        p->move(globalP.x() + m_pTableView->horizontalHeader()->sectionPosition(index) +
                (m_pTableView->horizontalHeader()->sectionSize(index) - p->width()) / 2,
                globalP.y() + 34);

        if (p->exec())
        {
            p->getFilterItems(filters);
            m_pKysecTableModel->setTypeFilters(filters);
            m_pKysecTableModel->refreshData(m_pSearchEdit->text().toLocal8Bit().data());
            updateStatisticsLabel();
        }

        delete p;
    }
    else
    {
        QMap<int, bool> filters;
        m_pKysecTableModel->getStatusFilters(filters);

        FilterSelectDialog* p = new FilterSelectDialog(filter_execctrl_status, this);
        p->setFilterItems(filters);
        p->resize(90, 120);
        p->move(globalP.x() + m_pTableView->horizontalHeader()->sectionPosition(index) +
                (m_pTableView->horizontalHeader()->sectionSize(index) - p->width()) / 2,
                globalP.y() + 34);

        if (p->exec())
        {
            p->getFilterItems(filters);
            m_pKysecTableModel->setStatusFilters(filters);
            m_pKysecTableModel->refreshData(m_pSearchEdit->text().toLocal8Bit().data());
            updateStatisticsLabel();
        }

        delete p;
    }
}

void KysecDataManage::fileProtectFilter(int index)
{
    if (index < 3)
        return;

    QPoint globalP(m_pTableView->mapToGlobal(QPoint(0, 0)));
    QMap<int, bool> filters;
    m_pKysecTableModel->getStatusFilters(filters);

    FilterSelectDialog* p = new FilterSelectDialog(filter_fileprotect_status, this);
    p->setFilterItems(filters);
    p->resize(90, 120);
    p->move(globalP.x() + m_pTableView->horizontalHeader()->sectionPosition(index) +
            (m_pTableView->horizontalHeader()->sectionSize(index) - p->width()) / 2,
            globalP.y() + 34);

    if (p->exec())
    {
        p->getFilterItems(filters);
        m_pKysecTableModel->setStatusFilters(filters);
        m_pKysecTableModel->refreshData(m_pSearchEdit->text().toLocal8Bit().data());
        updateStatisticsLabel();
    }

    delete p;
}

void KysecDataManage::kmodProtectFilter(int index)
{
    if (index < 3)
        return;

    QPoint globalP(m_pTableView->mapToGlobal(QPoint(0, 0)));
    QMap<int, bool> filters;
    m_pKysecTableModel->getStatusFilters(filters);

    FilterSelectDialog* p = new FilterSelectDialog(filter_kmodprotect_status, this);
    p->setFilterItems(filters);
    p->resize(90, 120);
    p->move(globalP.x() + m_pTableView->horizontalHeader()->sectionPosition(index) +
            (m_pTableView->horizontalHeader()->sectionSize(index) - p->width()) / 2,
            globalP.y() + 34);

    if (p->exec())
    {
        p->getFilterItems(filters);
        m_pKysecTableModel->setStatusFilters(filters);
        m_pKysecTableModel->refreshData(m_pSearchEdit->text().toLocal8Bit().data());
        updateStatisticsLabel();
    }

    delete p;
}

void KysecDataManage::updateStatisticsLabel()
{
    int sum = 0, distort = 0;
    if (NULL != m_pKysecTableModel)
        m_pKysecTableModel->getStatisticsData(sum, distort);

    if (m_type != kysec_filepro)
        m_pStatisticsLabel->setText(QString("<font color = #696969 >共 %1 行记录，被篡改 </font>").arg(sum)
                                + QString("<font color = #FF0000>%1</font>").arg(distort)
                                + QString("<font color = #696969 > 行</font>"));
    else
        m_pStatisticsLabel->setText(QString("<font color = #696969 >共 %1 行记录").arg(sum));
}

void KysecDataManage::slot_refreshBtnClicked()
{
    QString text = m_pSearchEdit->text();
    m_pKysecTableModel->refreshData("");
    updateStatisticsLabel();
}
void KysecDataManage::slot_searchBtnClicked()
{
    QString text = m_pSearchEdit->text();
    m_pKysecTableModel->refreshData(text.toLocal8Bit().data());
    updateStatisticsLabel();
}

void KysecDataManage::slot_addBtnClicked()
{
#ifndef DEBUG_TEST
    if (!checkFuncStatus())
    {
        KysecMessageBox* msgBox = new KysecMessageBox(this);

        if (FUNC_EXECTL == m_type)
            msgBox->showMsg(Msg_Warning, QString("执行控制功能未开启,禁止进行添加操作!"));
        else if (FUNC_FPRO == m_type)
            msgBox->showMsg(Msg_Warning, QString("文件保护功能未开启,禁止进行添加操作!"));
        else
            msgBox->showMsg(Msg_Warning, QString("内核模块保护功能未开启,禁止进行添加操作!"));

        return;
    }
#endif

    KysecFileDialog fileDialog(this);
    fileDialog.setWindowTitle(QString("添加"));
    if ( fileDialog.exec() == QDialog::Accepted)
    {
        QStringList list = fileDialog.selectedFiles();
        qDebug() << list << endl;
        ProcessAddWaitingDialog dialog(this);
        dialog.setPathList(m_type, fileDialog.selectedFiles());
        dialog.start();
        if (0 != dialog.result())
        {
            if (dialog.result() == -99)
            {
                KysecMessageBox* msgBox = new KysecMessageBox(this);
                msgBox->showMsg(Msg_Warning, dialog.error_msg());
                return;
            }
            else
            {
                KysecMessageBox* msgBox = new KysecMessageBox(this);
                msgBox->showMsg(Msg_Warning, dialog.error_msg());
//                m_pSearchEdit->clear();
                m_pKysecTableModel->refreshData(m_pSearchEdit->text().toLocal8Bit().data());
                updateStatisticsLabel();
                return;
            }
        }
        else
        {
            KysecMessageBox* msgBox = new KysecMessageBox(this);
            msgBox->showMsg(Msg_Complete, QString("添加所选文件、文件夹至白名单成功!"));
//            m_pSearchEdit->clear();
            m_pKysecTableModel->refreshData(m_pSearchEdit->text().toLocal8Bit().data());
            updateStatisticsLabel();
        }
    }
    else
    {
        updateStatisticsLabel();
        return ;
    }
}

void KysecDataManage::slot_updateBtnClicked()
{
#ifndef DEBUG_TEST
    if (!checkFuncStatus())
    {
        KysecMessageBox* box = new KysecMessageBox(this);

        if (FUNC_EXECTL == m_type)
            box->showMsg(Msg_Warning, QString("执行控制功能未开启,禁止进行更新操作!"));
        else if (FUNC_FPRO == m_type)
            box->showMsg(Msg_Warning, QString("文件保护功能未开启,禁止进行更新操作!"));
        else
            box->showMsg(Msg_Warning, QString("内核模块保护功能未开启,禁止进行更新操作!"));

        return;
    }
#endif

    KysecMessageBox* msgBox = new KysecMessageBox(this);
    if (msgBox->showMsg(Msg_Question, QString("更新操作不可逆,是否确定更新所选择的记录?")))
    {
        QStringList list = m_pKysecTableModel->getCheckedList();
        qDebug() << list << endl;
        ProcessUpdateWaitingDialog dialog(this);
        dialog.setPathList(m_type, list);
        dialog.start();
        if (0 != dialog.result())
        {
            if (dialog.result() == -99)
            {
                KysecMessageBox* msgBox = new KysecMessageBox(this);
                msgBox->showMsg(Msg_Warning, dialog.error_msg());
                return;
            }
            else
            {
                KysecMessageBox* msgBox = new KysecMessageBox(this);
                msgBox->showMsg(Msg_Warning, dialog.error_msg());
//                m_pSearchEdit->clear();
                m_pKysecTableModel->refreshData(m_pSearchEdit->text().toLocal8Bit().data());
                updateStatisticsLabel();
                return;
            }
        }
        else
        {
            KysecMessageBox* msgBox = new KysecMessageBox(this);
            msgBox->showMsg(Msg_Complete, QString("所选择的记录更新成功!"));
//            m_pSearchEdit->clear();
            m_pKysecTableModel->refreshData(m_pSearchEdit->text().toLocal8Bit().data());
            updateStatisticsLabel();
        }
        updateStatisticsLabel();
    }
}

void KysecDataManage::slot_deleteBtnClicked()
{
#ifndef DEBUG_TEST
    if (!checkFuncStatus())
    {
        KysecMessageBox* box = new KysecMessageBox(this);
        if (FUNC_EXECTL == m_type)
            box->showMsg(Msg_Warning, QString("执行控制功能未开启,禁止进行删除操作!"));
        else if (FUNC_FPRO == m_type)
            box->showMsg(Msg_Warning, QString("文件保护功能未开启,禁止进行删除操作!"));
        else
            box->showMsg(Msg_Warning, QString("内核模块保护功能未开启,禁止进行删除操作!"));

        return;
    }
#endif

    KysecMessageBox* msgBox = new KysecMessageBox(this);
    if (msgBox->showMsg(Msg_Question, QString("认证解除操作不可逆,是否确定解除所选择的记录的认证状态?")))
    {
        QStringList list = m_pKysecTableModel->getCheckedList();
        qDebug() << list << endl;
        ProcessDeleteWaitingDialog dialog(this);
        dialog.setPathList(m_type, list);
        dialog.start();
        if (0 != dialog.result())
        {
            if (dialog.result() == -99)
            {
                KysecMessageBox* msgBox = new KysecMessageBox(this);
                msgBox->showMsg(Msg_Warning, dialog.error_msg());
                return;
            }
            else
            {
                KysecMessageBox* msgBox = new KysecMessageBox(this);
                msgBox->showMsg(Msg_Warning, dialog.error_msg());
//                m_pSearchEdit->clear();
                m_pKysecTableModel->refreshData(m_pSearchEdit->text().toLocal8Bit().data());
                updateStatisticsLabel();
                return;
            }
        }
        else
        {
            KysecMessageBox* msgBox = new KysecMessageBox(this);
            msgBox->showMsg(Msg_Complete, QString("所选择的记录认证解除成功!"));
//            m_pSearchEdit->clear();
            m_pKysecTableModel->refreshData(m_pSearchEdit->text().toLocal8Bit().data());
            updateStatisticsLabel();
        }
        updateStatisticsLabel();
    }
}

void KysecDataManage::slot_doubleClicked(QModelIndex index)
{
    if (NULL == m_pKysecTableModel)
        return;

    if (!index.isValid())
        return;

    if (index.row() < 0 || index.row() >= m_pKysecTableModel->rowCount())
        return;

    if (index.column() == 1)
    {
        db_object obj;
        m_pKysecTableModel->getRowData(index.row(), obj);
        QClipboard *clipboard = QApplication::clipboard();   //获取系统剪贴板指针
        clipboard->setText(obj.fpath);                     //设置剪贴板内容</span>
    }
}

void KysecDataManage::slot_singleClicked(QModelIndex index)
{
    if (NULL == m_pKysecTableModel)
        return;

    if (!index.isValid())
        return;

    if (index.row() < 0 || index.row() >= m_pKysecTableModel->rowCount())
        return;

    if (index.column() == 0 && g_bAdmPrivilege)
    {
        m_pKysecTableModel->updateChecked(index.row());
    }
}

void KysecDataManage::slot_entered(QModelIndex index)
{
    if (NULL == m_pKysecTableModel)
        return;

    if (!index.isValid())
        return;

    //if (index.row() < 0 || index.row() >= m_pKysecTableModel->rowCount())
    if (index.column() != 1)
        return;

    db_object obj;
    m_pKysecTableModel->getRowData(index.row(), obj);

    if (m_type != kysec_filepro)
    {
        QString tip = QString("文件路径：%1\n摘  要  值：%2").arg(obj.fpath).arg(obj.hash);
        QToolTip::showText(QCursor::pos(), tip);
    }
    else
    {
        QString tip = QString("文件路径：%1").arg(obj.fpath);
        QToolTip::showText(QCursor::pos(), tip);
    }
}

void KysecDataManage::slot_checkedChanged(int count)
{
    if (!g_bAdmPrivilege)
        return ;

    if (count == 0)
    {
        QPalette palette = this->palette();

        m_pUpdateBtn->setIcon(QIcon(":/images/image/icon_update_gray.png"));
        palette.setColor(QPalette::WindowText, QColor("#8C8C8C"));
        m_pUpdateBtn->setPalette(palette);
        m_pUpdateBtn->setEnabled(false);

        m_pDeleteBtn->setIcon(QIcon(":/images/image/icon_delete_gray.png"));
        palette.setColor(QPalette::WindowText, QColor("#8C8C8C"));
        m_pDeleteBtn->setPalette(palette);
        m_pDeleteBtn->setEnabled(false);
    }
    else    {
        QPalette palette = this->palette();

        m_pUpdateBtn->setIcon(QIcon(":/images/image/icon_update.png"));
        palette.setColor(QPalette::WindowText, QColor("#121217"));
        m_pUpdateBtn->setPalette(palette);
        m_pUpdateBtn->setEnabled(true);

        m_pDeleteBtn->setIcon(QIcon(":/images/image/icon_delete.png"));
        palette.setColor(QPalette::WindowText, QColor("#121217"));
        m_pDeleteBtn->setPalette(palette);
        m_pDeleteBtn->setEnabled(true);
    }
}

void KysecDataManage::slot_updateKoStatusFailed(int res)
{
    KysecMessageBox* msgBox = new KysecMessageBox(this);
    if (res == 0)
        msgBox->showMsg(Msg_Warning, QString("内核模块未认证，无法修改防卸载状态!"));
    else
        msgBox->showMsg(Msg_Warning, QString("修改内核模块防卸载状态失败!"));
    return;
}

void KysecDataManage::slot_headerViewSectionClicked(int index)
{
    if (m_type == kysec_exectrl)
        execCtrlFilter(index);

    if (m_type == kysec_filepro)
        fileProtectFilter(index);

    if (m_type == kysec_kmodpro)
        kmodProtectFilter(index);
}

void KysecDataManage::slot_clear_search_edit()
{
    m_pSearchEdit->clear();
}

void KysecDataManage::slot_search_edit_text_changed(QString text)
{
    if (text.length() == 0)
        m_pClearAction->setVisible(false);
    else
        m_pClearAction->setVisible(true);
}
