#ifndef KYSECDATAMANAGE_H
#define KYSECDATAMANAGE_H

#include <QtWidgets/QWidget>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QTableView>
#include <QtWidgets/QToolTip>
#include <QtWidgets/QLabel>
#include <QtWidgets/QAction>

#include "CheckBoxHeaderView.h"
#include "KysecTableView.h"
#include "KysecTableModelBase.h"
#include "FilterSelectDialog.h"
#include "KysecItemDelegate.h"

class KysecDataManage : public QWidget
{
    Q_OBJECT

public:
    KysecDataManage(e_kysec_type type, QWidget *parent = 0);
    ~KysecDataManage();

    void refresh();

protected:
    bool eventFilter(QObject *watched, QEvent *event);

private:
    void initUI();
    void initConnection();

    bool checkFuncStatus();

    void execCtrlFilter(int index);
    void fileProtectFilter(int index);
    void kmodProtectFilter(int index);

    void updateStatisticsLabel();

signals:
    void signal_headerViewSectionClicked(int);

private slots:
    void slot_searchBtnClicked();
    void slot_refreshBtnClicked();
    void slot_addBtnClicked();
    void slot_updateBtnClicked();
    void slot_deleteBtnClicked();

    void slot_doubleClicked(QModelIndex index);
    void slot_singleClicked(QModelIndex index);
    void slot_entered(QModelIndex index);

    void slot_checkedChanged(int count);
    void slot_updateKoStatusFailed(int res);

    void slot_headerViewSectionClicked(int index);
    void slot_clear_search_edit();
    void slot_search_edit_text_changed(QString text);

private:
    QLabel* m_pContentLabel;

    QHBoxLayout *m_pSearchLayout;
    QHBoxLayout *m_pRefreshLayout;
    QLineEdit   *m_pSearchEdit;
    QPushButton *m_pRefreshBtn;
    QPushButton *m_pSearchBtn;
    QAction     *m_pClearAction;
    QWidget     *m_pSearchWidget;
    QToolButton *m_pAddBtn;
    //QToolButton *m_pRefreshBtn;
    QToolButton *m_pUpdateBtn;
    QToolButton *m_pDeleteBtn;
    QHBoxLayout *m_pFuncLayout;

    CheckBoxHeaderView *m_pCheckBoxHeaderView;
    KysecTableView *m_pTableView;
    KysecTableModelBase* m_pKysecTableModel;
    KysecItemDelegate *m_pKysecItemDelegate;
    bool m_bUnloadProtect;

    QLabel* m_pStatisticsLabel;

    QVBoxLayout *m_pMainLayout;

    e_kysec_type m_type;
};

#endif // KYSECDATAMANAGE_H
