#include "KysecItemDelegate.h"
#include "GlobalDef.h"
#include "IconHelper.h"
#include "KysecTableModelBase.h"

#include <QPainter>
#include <QAbstractTableModel>

KysecItemDelegate::KysecItemDelegate(int type, KysecTableModelBase *pModel, QWidget *parent)
    : QStyledItemDelegate(parent), m_type(type), m_pModel(pModel)
{
    m_space = 2;
}

void KysecItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
{
    QRect rect = option.rect;
    if (index.row() == m_hover_index.row() && m_hover_index.isValid() && g_bAdmPrivilege)
        painter->fillRect(rect, QColor("#E9EBEE"));
    else
        painter->fillRect(rect, QColor("#FFFFFF"));


    if (!index.isValid())
        return;

    whitelist_data obj;
    m_pModel->getWhlistData(index.row(), obj);
    QFont ft;
    ft.setPixelSize(12);

    QColor color;
    if (g_bAdmPrivilege)
    {
        color = QColor("#000000");
        if (obj.checked)
            color = QColor("#0160D8");
    }
    else
        color = QColor(0, 0, 0, 128);

    if (index.column() == 0)
    {
        ft = IconHelper::Instance()->getFont(12);
        if (obj.checked)
            drawText(painter, rect, QString("%1 %2").arg(QString(QChar(0xf046))).arg(index.row() + 1, 6, 10), Qt::AlignCenter, ft, color);
        else
            drawText(painter, rect, QString("%1 %2").arg(QString(QChar(0xf096))).arg(index.row() + 1, 6, 10), Qt::AlignCenter, ft, color);
    }

    if (index.column() == 1)
        drawText(painter, rect, obj.data.fpath, Qt::AlignVCenter, ft, color);

    if (index.column() == 2)
    {
        if (m_type == kysec_kmodpro)
        {
            painter->setRenderHint(QPainter::Antialiasing);
            QRect r1 = option.rect;
            QRect r(r1.x() + (r1.width() - 40)/2, r1.y() + (r1.height() - 16) / 2, 40, 16);
            drawBg(painter, r, obj.data.rmmodpro);
            drawSlider(painter, r, obj.data.rmmodpro);
        }
        else
            drawText(painter, rect, g_mapFileType.value(obj.data.type), Qt::AlignCenter, ft, color);
    }
    else if (index.column() == 3)
    {
        if (g_bAdmPrivilege)
        {
            if (obj.data.status == 1)
                color = QColor("#FF0000");
            else if (obj.data.exectl == exectl_sign_unknown)
                color = QColor("#FFA400");
            else
                color = QColor("#000000");
        }
        else
            color = QColor(0, 0, 0, 128);

        drawText(painter, rect, g_mapExectlSatus.value(get_exectl_status_type(obj.data.exectl, obj.data.status)), Qt::AlignCenter, ft, color);
    }
}

bool KysecItemDelegate::editorEvent(QEvent *event, QAbstractItemModel *model, const QStyleOptionViewItem &option, const QModelIndex &index)
{
    if(event->type()==QEvent::MouseButtonPress && g_bAdmPrivilege)
    {
        if (index.isValid() && index.column() == 2 && m_type == kysec_kmodpro)
        {
            int ret =  m_pModel->updateKoStatus(index.row());
            if (ret == 0)
                return true;
            else
                return false;
        }
    }

    return false;
}

void KysecItemDelegate::slot_hover_index_changed(QModelIndex index)
{
    m_hover_index = index;
//    m_pModel->reset();
}

void KysecItemDelegate::slot_selected_index_changed(QModelIndex index)
{
    m_selected_index = index;
    //    m_pModel->reset();
}

void KysecItemDelegate::drawBg(QPainter *painter, QRect rect, bool checked) const
{
    painter->save();
    painter->setPen(Qt::NoPen);

    if (g_bAdmPrivilege){
        if (!checked) {
            painter->setBrush(QColor("#C8CACE"));
        } else {
            painter->setBrush(QColor("#1778F0"""));
        }
    }
    else
        painter->setBrush(QColor("#ECECEC"));


    //    QRect rect_r(0, 0, rect.width(), rect.height());
    //半径为高度的一半
    int radius = rect.height() / 2;
    //圆的宽度为高度
    int circleWidth = rect.height();

    QPainterPath path;
    path.moveTo(rect.x() + radius, rect.y());
    path.arcTo(QRectF(rect.left(), rect.top(), circleWidth, circleWidth), 90, 180);
    path.lineTo(rect.x() + rect.width() - radius, rect.y() + rect.height());
    path.arcTo(QRectF(rect.x() + rect.width() - radius * 2, rect.top(), circleWidth, circleWidth), 270, 180);
    path.lineTo(rect.x() + radius, rect.y());

    painter->drawPath(path);
    painter->restore();
}

void KysecItemDelegate::drawSlider(QPainter *painter, QRect rect, bool checked) const
{
    painter->save();
    painter->setPen(Qt::NoPen);

    if (g_bAdmPrivilege)
        painter->setBrush(QColor("#FFFFFF"));
    else
        painter->setBrush(QColor("#E0E0E0"));

    //    QRect rect_r(0, 0, rect.width(), rect.height());
    int sliderWidth = rect.height() - m_space * 2;

    if (checked)
    {
        QRect sliderRect(rect.x() + m_space, rect.y() + m_space, sliderWidth, sliderWidth);
        painter->drawEllipse(sliderRect);
    }
    else
    {
        QRect sliderRect(rect.x() + rect.width() - m_space - sliderWidth, rect.y() + m_space, sliderWidth, sliderWidth);
        painter->drawEllipse(sliderRect);
    }

    painter->restore();
}

void KysecItemDelegate::drawText(QPainter *painter, QRect rect, QString text, Qt::AlignmentFlag flag, QFont font, QColor color) const
{
    QPen pen; //画笔
    pen.setColor(color);  //设置画笔颜色
    painter->setPen(pen);
    painter->setFont(font);

    QFontMetrics fontwidth(font);
    int size = fontwidth.width(text);
    if (size >= rect.width())
        text = fontwidth.elidedText(text, Qt::ElideMiddle, rect.width());

    painter->drawText(rect.x() + 10, rect.y(), rect.width() - 20, rect.height(), flag, text);
}
