#include "KysecMainDlg.h"
#include <QMovie>
#include <QPainter>

KysecMainDlg::KysecMainDlg(QWidget *parent)
    : QWidget(parent), m_isOut(false)
{
    initUI();
    initAnimation();
}

KysecMainDlg::~KysecMainDlg()
{

}

void KysecMainDlg::direct_enter_kysec_cfg_dialog()
{
    m_isOut = true;
    this->setOpacity(0);
    this->move(0, -600);
}

void KysecMainDlg::startAnimation()
{
    m_pKysecManageMain->initKysecStatus();
    if (m_isOut){
        m_pInGroup->start();
        m_isOut = false;
    }else{
        m_pOutGroup->start();
        m_isOut = true;
    }
}

void KysecMainDlg::initUI()
{
    setMinimumSize(WINDOW_WIDTH, WINDOW_HEIGHT);

    setAutoFillBackground(true);
    QPalette palette(this->palette());
    palette.setColor(QPalette::Background, QColor("#FFFFFF"));
    this->setPalette(palette);

    m_pBackgroundLabel = new QLabel(this);
    m_pBackgroundLabel->setFixedSize(BACKGROUND_WIDTH, BACKGROUND_HEIGHT);
    m_pBackgroundLabel->move(0, WINDOW_HEIGHT- BACKGROUND_HEIGHT);
    m_pBackgroundLabel->setScaledContents(true);
    QMovie *movie = new QMovie(":/images/image/wave.gif", QByteArray(), this);//背景路径，直接放静态图也是可以的
    m_pBackgroundLabel->setMovie(movie);
    movie->start();

    /*登录窗口*/
    m_pKysecManageMain = new KysecManageMain(this);

    connect(m_pKysecManageMain, SIGNAL(signal_close()), this, SIGNAL(signal_close()));
    connect(m_pKysecManageMain, SIGNAL(signal_minimize()), this, SIGNAL(signal_minimize()));
    connect(m_pKysecManageMain, SIGNAL(signal_showSettingDialog()), this, SIGNAL(signal_showSettingDialog()));
    connect(m_pKysecManageMain, SIGNAL(signal_showConfigureDialog()), this, SIGNAL(signal_showConfigureDialog()));
}

void KysecMainDlg::initAnimation()
{
    m_pEffect = new QGraphicsOpacityEffect(this);
    m_pEffect->setOpacity(1);
    this->setGraphicsEffect(m_pEffect);

    m_pOutAnimation = new QPropertyAnimation(this, "AnimationPos");
    m_pOutAnimation->setStartValue(QPointF(0, 0));
    m_pOutAnimation->setEndValue(QPointF(0, -600));
    m_pOutAnimation->setDuration(400);

    m_pInAnimation = new QPropertyAnimation(this, "AnimationPos");
    m_pInAnimation->setStartValue(QPointF(0, -600));
    m_pInAnimation->setEndValue(QPointF(0, 0));
    m_pInAnimation->setDuration(400);


    m_pOutOpacityAnimation = new QPropertyAnimation(this, "AnimationOpacity");
    m_pOutOpacityAnimation->setStartValue(1);
    m_pOutOpacityAnimation->setEndValue(0);
    m_pOutOpacityAnimation->setDuration(400);

    m_pInOpacityAnimation = new QPropertyAnimation(this, "AnimationOpacity");
    m_pInOpacityAnimation->setStartValue(0);
    m_pInOpacityAnimation->setEndValue(1);
    m_pInOpacityAnimation->setDuration(400);

    m_pInGroup = new QParallelAnimationGroup(this);
    m_pOutGroup = new QParallelAnimationGroup(this);

    m_pInGroup->addAnimation(m_pInAnimation);
    m_pInGroup->addAnimation(m_pInOpacityAnimation);
    m_pOutGroup->addAnimation(m_pOutAnimation);
    m_pOutGroup->addAnimation(m_pOutOpacityAnimation);

    connect(m_pInAnimation, SIGNAL(valueChanged(QVariant)), this, SLOT(update()));
    connect(m_pOutAnimation, SIGNAL(valueChanged(QVariant)), this, SLOT(update()));
}
