#include "KysecManage.h"
#include <QtWidgets/QApplication>
#include <QtWidgets/QDesktopWidget>
#include "Common.h"

KysecManage::KysecManage(QWidget *parent)
    : FlatDropWidget(parent)
{
    initUI();
    initConnection();
}

void KysecManage::enter_cfg_dialog()
{
    m_pKysecMainDlg->direct_enter_kysec_cfg_dialog();
    m_pKysecConfigureDlg->slot_showDialog();
}

void KysecManage::initUI()
{
    this->setWindowTitle(QString("麒麟安全管理工具"));
    this->setWindowIcon(QIcon(":images/logo/kysec_logo/48.png"));
    this->setFixedSize(WINDOW_WIDTH, WINDOW_HEIGHT);
    QDesktopWidget *pDeskTop = QApplication::desktop();
    this->move((pDeskTop->width() - width()) / 2, (pDeskTop->height() - height()) / 2);

    m_pKysecMainDlg = new KysecMainDlg(this);
    m_pKysecMainDlg->resize(WINDOW_WIDTH, WINDOW_HEIGHT);

    m_pKysecConfigureDlg = new KysecConfigureDlg(this);
    m_pKysecConfigureDlg->resize(WINDOW_WIDTH, WINDOW_HEIGHT);
    m_pKysecConfigureDlg->move(0, 0);
    m_pKysecConfigureDlg->lower();
    m_pKysecConfigureDlg->hide();

    m_pKysecSettingDlg = new KysecSettingDlg(this);
    m_pKysecSettingDlg->resize(WINDOW_WIDTH, WINDOW_HEIGHT);
    m_pKysecSettingDlg->move(0, 0);
    m_pKysecSettingDlg->lower();
    m_pKysecSettingDlg->hide();
}

void KysecManage::initConnection()
{
    connect(m_pKysecMainDlg, SIGNAL(signal_close()), this, SLOT(slot_close()));
    connect(m_pKysecMainDlg, SIGNAL(signal_minimize()), this, SLOT(slot_minimize()));

    connect(m_pKysecMainDlg->OutAnimation(), SIGNAL(valueChanged(QVariant)), m_pKysecConfigureDlg, SLOT(update()));
    connect(m_pKysecConfigureDlg, SIGNAL(signal_returnBtnClicked()), this, SLOT(slot_switchDlg()));
    connect(m_pKysecConfigureDlg, SIGNAL(signal_minimizeBtnClicked()), this, SLOT(slot_minimize()));
    connect(m_pKysecConfigureDlg, SIGNAL(signal_closeBtnClicked()), this, SLOT(slot_close()));
    connect(m_pKysecMainDlg->InAnimation(), SIGNAL(finished()), m_pKysecConfigureDlg, SLOT(hide()));
    connect(m_pKysecMainDlg, SIGNAL(signal_showConfigureDialog()), m_pKysecConfigureDlg, SLOT(slot_showDialog()));
    connect(m_pKysecMainDlg, SIGNAL(signal_showConfigureDialog()), this, SLOT(slot_switchDlg()));

    connect(m_pKysecMainDlg->OutAnimation(), SIGNAL(valueChanged(QVariant)), m_pKysecSettingDlg, SLOT(update()));
    connect(m_pKysecSettingDlg, SIGNAL(signal_returnBtnClicked()), this, SLOT(slot_switchDlg()));
    connect(m_pKysecSettingDlg, SIGNAL(signal_minimizeBtnClicked()), this, SLOT(slot_minimize()));
    connect(m_pKysecSettingDlg, SIGNAL(signal_closeBtnClicked()), this, SLOT(slot_close()));
    connect(m_pKysecMainDlg->InAnimation(), SIGNAL(finished()), m_pKysecSettingDlg, SLOT(hide()));
    connect(m_pKysecMainDlg, SIGNAL(signal_showSettingDialog()), m_pKysecSettingDlg, SLOT(slot_showDialog()));
    connect(m_pKysecMainDlg, SIGNAL(signal_showSettingDialog()), this, SLOT(slot_switchDlg()));
}

void KysecManage::slot_switchDlg()
{
    m_pKysecMainDlg->startAnimation();
}

void KysecManage::slot_close()
{
    this->close();
}

void KysecManage::slot_minimize()
{
    this->showMinimized();
}
