#include "KysecManageMain.h"
#include <QtWidgets/QApplication>
#include <QtWidgets/QDesktopWidget>
#include <QIcon>
#include <QMouseEvent>
#include <QKeyEvent>
#include <QDebug>
#include <QProcess>
#include <QtWidgets/QSpacerItem>

#include <sys/types.h>
#include <unistd.h>
#include "Common.h"
#include "kysec/status.h"
#include "IconHelper.h"
#include "GlobalHelper.h"
#include "KysecMessageBox.h"
#include "kylinos-type.h"

#define KYLIN_USER_GUIDE_PATH "/"
#define KYLIN_USER_GUIDE_SERVICE "com.kylinUserGuide.hotel"
//    ----snprintf(service_name, SERVICE_NAME_SIZE, "%s_%d",KYLIN_USER_GUIDE_SERVICE,getuid());
#define KYLIN_USER_GUIDE_INTERFACE "com.guide.hotel"

#define SERVICE_NAME_SIZE 1024

KysecManageMain::KysecManageMain(QWidget *parent)
    : QWidget(parent)
{
    m_pMainMenu = new MainMenu(this);
    m_pAboutDialog = new AboutDialog(this);
    m_pAboutDialog->setVisible(false);

    initUI();
    initConnection();
    initKysecStatus();
}

KysecManageMain::~KysecManageMain()
{
    delete m_pMainMenu;
    delete m_pAboutDialog;
}

void KysecManageMain::initUI()
{
    setAttribute(Qt::WA_TranslucentBackground,true);  //背景透明
    setWindowFlags(Qt::FramelessWindowHint
                   |Qt::WindowStaysOnTopHint);//无边框,置顶


    resize(WINDOW_WIDTH, WINDOW_HEIGHT);
    QPalette palette = this->palette();
    QFont ft;

    m_pTitleBar = new TitleBar(this);
    m_pTitleBar->hideLogo();
    m_pTitleBar->setBackgroundColor("#FFFFFF");
    m_pTitleBar->getReturnBtn()->setVisible(false);
    m_pTitleBar->move(0, 0);

    m_pLogoLabel = new QLabel(this);
    QPixmap pix(":/images/logo/kysec_logo/128.png");
    m_pLogoLabel->setPixmap(pix);
    m_pLogoLabel->setFixedSize(128, 128);
    m_pLogoLabel->move(140, 120);

    m_pMainLabel = new QLabel(QString("麒麟安全管理工具"), this);
//    m_pDescLabel = new QLabel(QString("提供系统执行控制和文件保护机制，保护系统安全"), this);
//    m_pDescLabel = new QLabel(QString("提供对应用程序执行控制，内核模块加卸载保护和文件的防篡改保护"), this);
    palette.setColor(QPalette::WindowText, QColor("#121217"));
    ft.setPixelSize(50);
    m_pMainLabel->setFont(ft);
    m_pMainLabel->setPalette(palette);
    m_pMainLabel->setFixedSize(480, 70);
    m_pMainLabel->move(290, 130);

    palette.setColor(QPalette::WindowText, QColor("#8C8C8C"));
    ft.setPixelSize(16);
    m_pDescLabel = new QLabel(QString(" 检查应用程序和文件的完整性,保护系统运行环境安全可靠"), this);
    m_pDescLabel->setFont(ft);
    m_pDescLabel->setPalette(palette);
    m_pDescLabel->setFixedSize(920, 20);
    m_pDescLabel->move(290, 205);

    m_pConfigToolBtn = new QToolButton(this);
    m_pConfigToolBtn->setText(QString("安全配置"));
    m_pConfigToolBtn->setToolButtonStyle(Qt::ToolButtonTextOnly);
    m_pConfigToolBtn->setObjectName("ConfigToolBtn");
    m_pConfigToolBtn->setIconSize(QSize(20, 20));
    m_pConfigToolBtn->installEventFilter(this);
    m_pConfigToolBtn->setFixedSize(220, 50);
    palette.setColor(QPalette::WindowText, QColor("#FFFFFF"));
    ft.setPixelSize(18);
    m_pConfigToolBtn->setFont(ft);
    m_pConfigToolBtn->setPalette(palette);
    m_pConfigToolBtn->move(350, 330);

    palette.setColor(QPalette::WindowText, QColor("#FFFFFF"));
    palette.setColor(QPalette::WindowText, QColor("#121217"));
    ft.setPixelSize(12);
    m_pModeLabel = new QLabel(this);
    QPixmap pix2(":/images/image/disable_2x.png");
    m_pModeLabel->setPixmap(pix2.scaled(pix2.size()));
    m_pModeLabel->move(700, 125);

    m_pSpliteLabel = new QLabel(QString("丨"), this);
    m_pSpliteLabel->setFont(ft);
    m_pSpliteLabel->setPalette(palette);
    m_pSpliteLabel->setScaledContents(true);
    m_pSpliteLabel->move(360, 500);
    m_pSpliteLabel->setVisible(false);

    m_pSettingLabelBtn = new KysecLabelBtn(this);
    //    m_pSettingLabelBtn->setObjectName(QString("ConfigLabelBtn"));
    m_pSettingLabelBtn->setText(QString("麒麟系统设置"));
    m_pSettingLabelBtn->setFont(ft);
    //    m_pSettingLabelBtn->setText(QString("%1   麒麟系统设置").arg(QString(QChar(0xf085))));

    //    QString underline = QString("%1   <u>麒麟系统设置</u>").arg(QString(QChar(0xf085)));
    //    QString common = QString("%1   麒麟系统设置").arg(QString(QChar(0xf085)));
    //    m_pSettingLabelBtn->setDisplayText(underline, common);

    //    m_pSettingLabelBtn->setFont(IconHelper::Instance()->getFont(12));
    m_pSettingLabelBtn->setPalette(palette);
    m_pSettingLabelBtn->setFixedWidth(120);
    m_pSettingLabelBtn->setAlignment(Qt::AlignLeft);
    m_pSettingLabelBtn->setVisible(false);

//    m_pBottomLayout = new QHBoxLayout();
//    m_pBottomLayout->setSpacing(10);
//    m_pBottomLayout->addStretch(0);
//    m_pBottomLayout->addWidget(m_pModeLabel);
//    m_pBottomLayout->addWidget(m_pSpliteLabel);
//    m_pBottomLayout->addWidget(m_pSettingLabelBtn);
//    m_pBottomLayout->addStretch(0);
//    m_pBottomLayout->setContentsMargins(0, 0, 0, 0);

//    m_pLayout = new QVBoxLayout();
//    m_pLayout->setSpacing(0);
//    m_pLayout->addWidget(m_pTitleBar);
////    m_pLayout->addSpacing(48);
////    m_pLayout->addWidget(m_pLogoLabel, 0, Qt::AlignCenter);
////    m_pLayout->addSpacing(22);
////    m_pLayout->addWidget(m_pMainLabel, 0, Qt::AlignCenter);
////    m_pLayout->addSpacing(14);
////    m_pLayout->addWidget(m_pDescLabel, 0, Qt::AlignCenter);
//    m_pLayout->addSpacing(300);
//    m_pLayout->addWidget(m_pConfigToolBtn, 0, Qt::AlignCenter);
//    m_pLayout->addSpacing(120);
//    //    m_pLayout->addWidget(m_pSettingToolBtn, 0, Qt::AlignCenter);
//    m_pLayout->addLayout(m_pBottomLayout);
//    m_pLayout->addStretch(0);

//    m_pLayout->setContentsMargins(0, 0, 0 , 0);
//    setLayout(m_pLayout);
}

void KysecManageMain::initConnection()
{
    connect(m_pTitleBar->getCloseBtn(), SIGNAL(clicked(bool)), this, SIGNAL(signal_close()));
    connect(m_pTitleBar->getMinimizeBtn(), SIGNAL(clicked()), this, SIGNAL(signal_minimize()));
    connect(m_pTitleBar->getMenuBtn(), SIGNAL(clicked()), this, SLOT(slot_showmenu()));

    connect(m_pMainMenu, SIGNAL(signal_showNewCharacter()), this, SLOT(slot_showNewCharacter()));
    connect(m_pMainMenu, SIGNAL(signal_systemSetting()), this, SLOT(slot_settingBtnClicked()));
    connect(m_pMainMenu, SIGNAL(signal_showAboutUs()), this, SLOT(slot_showAboutUs()));

    connect(m_pConfigToolBtn, SIGNAL(clicked(bool)), this, SLOT(slot_configBtnClicked()));
//    connect(m_pSettingLabelBtn, SIGNAL(on_Clicked()), this, SLOT(slot_settingBtnClicked()));
}

void KysecManageMain::initKysecStatus()
{
    int status = kysec_getstatus();
    if (status == KYSEC_STATUS_NORMAL)
    {
        m_pModeLabel->setPixmap(QPixmap(":/images/image/enforcing_2x.png"));
    }
    else if (status == KYSEC_STATUS_SOFTMODE)
    {
//        m_pModeLabel->setText(QString("当前模式： 记录模式"));
        m_pModeLabel->setPixmap(QPixmap(":/images/image/record_2x.png"));
    }
    else
    {
        m_pModeLabel->setPixmap(QPixmap(":/images/image/disable_2x.png"));
    }
}

void KysecManageMain::enter_kysec_cfg_dialog()
{
    slot_configBtnClicked();
}

bool KysecManageMain::eventFilter(QObject *watched, QEvent *event)
{
    //    if (NULL != m_pSettingToolBtn && watched == m_pSettingToolBtn)
    //    {
    //        if (event->type() == QEvent::Enter)
    //        {
    //            m_pSettingToolBtn->setIcon(QIcon(":/images/image/icon_config.png"));
    //        }
    //        else if (event->type() == QEvent::Leave)
    //        {
    //            m_pSettingToolBtn->setIcon(QIcon(":/images/image/icon_config_black.png"));
    //        }
    //    }

    return QWidget::eventFilter(watched, event);
}

void KysecManageMain::keyPressEvent(QKeyEvent *event)
{
    if(event->modifiers() == Qt::ControlModifier)
    {

    }
    else if(event->key() == Qt::Key_F1)
    {
        if(!daemonIsNotRunning())
        {
            //增加标题栏帮助菜单、F1快捷键打开用户手册
            showGuide("kysec-ui-pkexec");
        }
    }

    QWidget::keyPressEvent(event);
}

void KysecManageMain::slot_showmenu()
{
    //设置主菜单出现的位置
    QPoint p = rect().topRight();
    p.setX(p.x() - 180);
    p.setY(p.y() + 35);
    m_pMainMenu->exec(this->mapToGlobal(p));
}

void KysecManageMain::slot_showNewCharacter()
{
    if(kylin_os_check_is_desktop() == true)
    {
        if(!daemonIsNotRunning())
        {
            //增加标题栏帮助菜单、F1快捷键打开用户手册
            showGuide("kysec-ui-pkexec");
        }
    }
    else
    {
        QProcess *m_process = new QProcess();
        m_process->start("sh", QStringList() << "-c" << "atril /usr/share/doc/KysecManual/*.pdf");
    }
}

void KysecManageMain::slot_showAboutUs()
{
    AboutDialog* dialog = new AboutDialog(this);
    dialog->setAttribute(Qt::WA_DeleteOnClose);
    dialog->exec();
}

void KysecManageMain::slot_settingBtnClicked()
{
#ifndef DEBUG_TEST
    int ret = kysec_getstatus();
    if (ret < 0)
    {
        KysecMessageBox* msgBox = new KysecMessageBox(this);
        msgBox->showMsg(Msg_Information, QString("KYSEC 安全状态获取失败，请检查系统 KYSEC 安全模式运行状态!"));
        return;
    }

    if (KYSEC_STATUS_DISABLED == ret)
    {
        KysecMessageBox* msgBox = new KysecMessageBox(this);
        msgBox->showMsg(Msg_Information, QString("KYSEC 安全模块尚未启动，请先启动 KYSEC 安全模块!"));
        return;
    }
#endif

    emit signal_showSettingDialog();
}

void KysecManageMain::slot_configBtnClicked()
{
#ifndef DEBUG_TEST
    int ret = kysec_getstatus();
    if (ret < 0)
    {
        KysecMessageBox* msgBox = new KysecMessageBox(this);
        msgBox->showMsg(Msg_Information, QString("KYSEC 安全状态获取失败，请检查系统 KYSEC 安全模式运行状态!"));
        return;
    }

    if (KYSEC_STATUS_DISABLED == ret)
    {
        KysecMessageBox* msgBox = new KysecMessageBox(this);
        msgBox->showMsg(Msg_Information, QString("KYSEC 安全模块尚未启动，请先启动 KYSEC 安全模块!"));
        return;
    }
#endif

    emit signal_showConfigureDialog();
}


int KysecManageMain::daemonIsNotRunning()
{
    char service_name[SERVICE_NAME_SIZE];
    memset(service_name, 0, SERVICE_NAME_SIZE);
    snprintf(service_name, SERVICE_NAME_SIZE, "%s_%d",KYLIN_USER_GUIDE_SERVICE,getuid());
    QDBusConnection conn = QDBusConnection::sessionBus();
    if (!conn.isConnected())
        return 0;

    QDBusReply<QString> reply = conn.interface()->call("GetNameOwner", service_name);
    return reply.value() == "";
}


void KysecManageMain::showGuide(QString appName)
{
    qDebug() << Q_FUNC_INFO << appName;
    //bool bRet  = false;

    char service_name[SERVICE_NAME_SIZE];
    memset(service_name, 0, SERVICE_NAME_SIZE);
    snprintf(service_name, SERVICE_NAME_SIZE, "%s_%d",KYLIN_USER_GUIDE_SERVICE, getuid());
    // 用来构造一个在D-Bus上传递的Message
    QDBusMessage m = QDBusMessage::createMethodCall(QString(service_name),KYLIN_USER_GUIDE_PATH,KYLIN_USER_GUIDE_INTERFACE,"showGuide");
    // 给QDBusMessage增加一个参数;
    // 这是一种比较友好的写法，也可以用setArguments来实现
    m << appName;

    // 发送Message
    QDBusMessage response = QDBusConnection::sessionBus().call(m);
    // 判断Method是否被正确返回
    if (response.type()== QDBusMessage::ReplyMessage)
    {
        // QDBusMessage的arguments不仅可以用来存储发送的参数，也用来存储返回值;
        //bRet = response.arguments().at(0).toBool();
    }
    else {
        qDebug()<<"showGuide In fail!\n";
    }

    //qDebug()<<"bRet:"<<bRet;
}
