#include "KysecMessageBox.h"
#include "IconHelper.h"
#include "Common.h"

#include <QVariant>

KysecMessageBox::KysecMessageBox(QWidget *parent) : FlatDropWidget(parent)
{
    initUI();
    this->setAttribute(Qt::WA_DeleteOnClose);
    this->setWindowFlags(Qt::FramelessWindowHint|Qt::Tool );

    m_pTimer = new QTimer(this);
    m_counter = 3;
    m_pTimer->setInterval(1000);
    connect(m_pTimer, SIGNAL(timeout()), this, SLOT(slot_timerout()));
}

KysecMessageBox::~KysecMessageBox()
{
    if (m_pTimer->isActive())
        m_pTimer->stop();

    delete m_pTimer;
}

int KysecMessageBox::showMsg(MsgType type, QString msg)
{
    if (type == Msg_Question)
    {
        m_pTitleBar->setLogoLabel(QString("询问"));
        m_pIconLabel->setPixmap(QPixmap(":/images/image/msgbox_icon/2x/icon_question_2x.png"));
        m_pOKBtn->setProperty("MsgType", "Question");
        m_pCancelBtn->setProperty("MsgType", "Question");
        m_pCancelBtn->setVisible(true);
    }
    else if (type == Msg_Information)
    {
        m_pTitleBar->setLogoLabel(QString("提示"));
        m_pIconLabel->setPixmap(QPixmap(":/images/image/msgbox_icon/2x/icon_remind_2_2x.png"));
        m_pOKBtn->setProperty("MsgType", "Information");
        m_pCancelBtn->setProperty("MsgType", "Information");
        m_pCancelBtn->setVisible(false);
    }
    else if (type == Msg_Warning)
    {
        m_pTitleBar->setLogoLabel(QString("警告"));
        m_pIconLabel->setPixmap(QPixmap(":/images/image/msgbox_icon/2x/icon_waring_2x.png"));
        m_pOKBtn->setProperty("MsgType", "Warning");
        m_pCancelBtn->setProperty("MsgType", "Warning");
        m_pCancelBtn->setVisible(false);
    }
    else
    {
        m_pTitleBar->setLogoLabel(QString("完成"));
        m_pIconLabel->setPixmap(QPixmap(":/images/image/msgbox_icon/2x/icon_finish_2x.png"));
        m_pOKBtn->setProperty("MsgType", "Complete");
        m_pOKBtn->setText("确认 (3)");
        m_pCancelBtn->setProperty("MsgType", "Complete");
        m_pCancelBtn->setVisible(false);
        m_pTimer->start();
    }

    m_pLabel->setText(msg);
    return this->exec();
}

void KysecMessageBox::slot_okBtnClicked()
{
    done(1);
    this->close();
}

void KysecMessageBox::slot_timerout()
{
    m_counter--;
    m_pOKBtn->setText(QString("确认 (%1)").arg(m_counter));
    if (m_counter == 0)
    {
        m_pTimer->stop();
        slot_okBtnClicked();
    }
}

void KysecMessageBox::initUI()
{
    this->setFixedSize(420, 240);
    setAutoFillBackground(true);
    QPalette palette = this->palette();
    palette.setBrush(this->backgroundRole(), QColor("#FFFFFF"));
    this->setPalette(palette);

    m_pTitleBar = new TitleBar(this);
    m_pTitleBar->resize(COMMON_DIALOG_WIDTH, TITLEBAR_HEIGHT);
    m_pTitleBar->setBackgroundColor("#0181EC");
    m_pTitleBar->getMinimizeBtn()->setVisible(false);
    m_pTitleBar->getMenuBtn()->setVisible(false);
    m_pTitleBar->getReturnBtn()->setVisible(false);
    m_pTitleBar->setLogoLabel(QString("KYSEC 添加白名单"), 14, QString("#FEFEFE"));
    m_pTitleBar->setLogoIcon(":/images/logo/kysec_logo_white/24.png");
    m_pTitleBar->setCloseIcon(":/images/image/close_white.png");
    m_pTitleBar->getCloseBtn()->setObjectName("WhiteCloseBtn");
    connect(m_pTitleBar->getCloseBtn(), SIGNAL(clicked(bool)), this, SLOT(close()));

    m_pIconLabel = new QLabel(this);
    m_pIconLabel->setFixedSize(72, 72);
    m_pIconLabel->setPixmap(QPixmap(":/images/image/msgbox_icon/2x/icon_finish_2x.png"));

    m_pLabel = new QLabel(QString("白名单文件添加完成!"), this);
    palette.setColor(QPalette::WindowText, QColor("#484B4F"));
    QFont ft;
    ft.setPixelSize(14);
    m_pLabel->setPalette(palette);
    m_pLabel->setFont(ft);
    m_pLabel->setScaledContents(true);
    m_pLabel->setWordWrap(true);
    m_pLabel->setFixedWidth(240);

    QHBoxLayout *m_pHBoxLayout = new QHBoxLayout();
    m_pHBoxLayout->addWidget(m_pIconLabel, 0, Qt::AlignVCenter);
    m_pHBoxLayout->addSpacing(20);
    m_pHBoxLayout->addWidget(m_pLabel, 0, Qt::AlignVCenter);
    m_pHBoxLayout->setContentsMargins(60, 20, 60, 30);
    m_pHBoxLayout->setSpacing(0);

    m_pWidget = new QWidget(this);
    m_pWidget->setObjectName("MsgBoxWidget");
    m_pWidget->setFixedSize(420, 150);
    m_pWidget->setLayout(m_pHBoxLayout);
    m_pWidget->move(0, 40);

    ft.setPixelSize(18);
    m_pOKBtn = new QPushButton(QString("确认"), this);
    m_pOKBtn->setFixedSize(80, 30);
    m_pOKBtn->setObjectName("KysecMessageBoxBtn");
    m_pOKBtn->setFont(ft);
    connect(m_pOKBtn, SIGNAL(clicked(bool)), this, SLOT(slot_okBtnClicked()));
    m_pOKBtn->move(316, 200);

    m_pCancelBtn = new QPushButton(QString("取消"), this);
    m_pCancelBtn->setFixedSize(80, 30);
    m_pCancelBtn->setObjectName("KysecMessageBoxBtn");
    m_pCancelBtn->setFont(ft);
    connect(m_pCancelBtn, SIGNAL(clicked(bool)), this, SLOT(close()));
    m_pCancelBtn->move(220, 200);
}
