#include "KysecSettingDlg.h"
#include "IconHelper.h"
#include <QtWidgets/QListView>
#include <QPalette>

#include "GlobalDef.h"
#include "kysec/status.h"
#include "kysec/status_dbus.h"
#include "KysecMessageBox.h"
#include "GlobalHelper.h"
#include "Common.h"

KysecSettingDlg::KysecSettingDlg(QWidget *parent)
    : QDialog(parent)
{
    setWindowFlags(Qt::FramelessWindowHint);
    initUI();
    initConnections();
}

KysecSettingDlg::~KysecSettingDlg()
{

}

void KysecSettingDlg::initUI()
{
    resize(WINDOW_WIDTH, WINDOW_HEIGHT);

    QPalette palette = this->palette();
    QFont font;

    setAutoFillBackground(true);
    palette.setColor(QPalette::Background, QColor("#FFFFFF"));
    this->setPalette(palette);

    m_pTitleBar = new TitleBar(this);
    m_pTitleBar->setBackgroundColor("#E4E7EA");
//    m_pTitleBar->getMinimizeBtn()->setVisible(false);
    m_pTitleBar->getMenuBtn()->setVisible(false);
//    m_pTitleBar->getCloseBtn()->setVisible(false);
    m_pTitleBar->setLogoLabel(QString("麒麟安全管理工具 - 状态设置"));

    m_pMainLabel = new QLabel(QString("将计算机设置为更安全的运行状态"), this);
    palette.setColor(QPalette::WindowText, QColor("#004FB6"));
    font.setPixelSize(24);
    m_pMainLabel->setPalette(palette);
    m_pMainLabel->setFont(font);
    m_pMainLabel->setScaledContents(true);

    m_pDescLabel = new QLabel(QString("提供执行控制、文件保护、内核模块保护等安全功能，让系统更安全稳定"), this);
    palette.setColor(QPalette::WindowText, QColor("#4B4E51"));
    font.setPixelSize(14);
    m_pDescLabel->setPalette(palette);
    m_pDescLabel->setFont(font);
    m_pDescLabel->setScaledContents(true);

    m_pModeLabel = new QLabel(QString("运行模式:"), this);
    palette.setColor(QPalette::WindowText, QColor("#26292D"));
    font.setPixelSize(16);
    font.setBold(false);
    m_pModeLabel->setPalette(palette);
    m_pModeLabel->setFont(font);
    m_pModeLabel->setScaledContents(true);

    m_pModeComboBox = new QComboBox(this);
    m_pModeComboBox->setObjectName("ModeComboBox");
    m_pModeComboBox->setFixedSize(120, 30);
    QListView *listview = new QListView(this);
    font.setPixelSize(14);
    listview->setFont(font);
    m_pModeComboBox->setView(listview);
    m_pModeComboBox->addItem(QIcon(":/images/image/Mandatory.png"), QString("强制模式"));
    m_pModeComboBox->addItem(QIcon(":/images/image/record.png"), QString("记录模式"));
    m_pModeComboBox->setCurrentIndex(0);
//    m_pModeComboBox->setProperty("ModeComboBox", "Normal");

    m_pModeLayout = new QHBoxLayout();
    m_pModeLayout->addWidget(m_pModeLabel);
    m_pModeLayout->addSpacing(10);
    m_pModeLayout->addWidget(m_pModeComboBox);
    m_pModeLayout->setContentsMargins(20, 0, 20, 0);

    m_pComboBoxModeWidget = new QWidget(this);
    m_pComboBoxModeWidget->setObjectName("ComboBoxModeWidget");
    m_pComboBoxModeWidget->setFixedSize(240, 44);
    m_pComboBoxModeWidget->setLayout(m_pModeLayout);

    m_pModeVLayout = new QVBoxLayout();
    m_pModeVLayout->addWidget(m_pMainLabel);
//    m_pModeVLayout->addSpacing(18);
    m_pModeVLayout->addWidget(m_pDescLabel);
    m_pModeVLayout->setContentsMargins(0, 50, 0, 30);

    m_pModeHLayout = new QHBoxLayout();
    m_pModeHLayout->addLayout(m_pModeVLayout);
    m_pModeHLayout->addStretch(1);
    m_pModeHLayout->addWidget(m_pComboBoxModeWidget);
    m_pModeHLayout->setContentsMargins(0, 0, 0, 0);

    m_pModeWidget = new QWidget(this);
    m_pModeWidget->setObjectName("ModeWidget");
    m_pModeWidget->setLayout(m_pModeHLayout);
    m_pModeWidget->setFixedHeight(136);

    m_pExecCtrl = new KysecFunctionWidget(this);
    m_pExecCtrl->setText(QString("执行控制"), QString("控制系统应用程序的执行及动态库加载"), QString(":/images/image/exectl_icon.png"));

    m_pFileProtect = new KysecFunctionWidget(this);
    m_pFileProtect->setText(QString("文件保护"), QString("提供对指定文件的完整性保护，防篡改、删除"), QString(":/images/image/file_protext_icon.png"));

    m_pKModProtect = new KysecFunctionWidget(this);
    m_pKModProtect->setText(QString("内核模块保护"), QString("控制系统内核模块的加载和卸载"), QString(":/images/image/kernel_protect_icon.png"));

    QString privilege = g_bAdmPrivilege ? "true" : "false";
    m_pExecCtrlWidget = new QWidget(this);
    m_pExecCtrlWidget->setObjectName("ExecCtrlWidget");
    m_pExecCtrlLayout = new QHBoxLayout();
    m_pExecCtrlLayout->addWidget(m_pExecCtrl);
    m_pExecCtrlLayout->setContentsMargins(0, 0, 0, 0);
    m_pExecCtrlWidget->setLayout(m_pExecCtrlLayout);
    m_pExecCtrlWidget->setProperty("Privilege", privilege);


    m_pFileProtectWidget = new QWidget(this);
    m_pFileProtectWidget->setObjectName("FileProtectWidget");
    m_pFileProtectLayout = new QHBoxLayout();
    m_pFileProtectLayout->addWidget(m_pFileProtect);
    m_pFileProtectLayout->setContentsMargins(0, 0, 0, 0);
    m_pFileProtectWidget->setLayout(m_pFileProtectLayout);
    m_pFileProtectWidget->setProperty("Privilege", privilege);

    m_pKModProtectWidget = new QWidget(this);
    m_pKModProtectWidget->setObjectName("KModProtectWidget");
    m_pKModProtectLayout = new QHBoxLayout();
    m_pKModProtectLayout->addWidget(m_pKModProtect);
    m_pKModProtectLayout->setContentsMargins(0, 0, 0, 0);
    m_pKModProtectWidget->setLayout(m_pKModProtectLayout);
    m_pKModProtectWidget->setProperty("Privilege", privilege);

    m_pGridLayout = new QGridLayout();
    m_pGridLayout->addWidget(m_pExecCtrlWidget, 0, 0, 1, 1);
    m_pGridLayout->addWidget(m_pFileProtectWidget, 0, 1, 1, 1);
    m_pGridLayout->addWidget(m_pKModProtectWidget, 1, 0, 1, 1);

    m_pGridLayout->setSpacing(20);
    m_pGridLayout->setRowStretch(0, 1);
    m_pGridLayout->setRowStretch(1, 1);
    m_pGridLayout->setColumnStretch(0, 1);
    m_pGridLayout->setColumnStretch(1, 1);
    m_pGridLayout->setContentsMargins(0, 20, 0, 20);

    m_pVLayout = new QVBoxLayout();
    m_pVLayout->addWidget(m_pModeWidget);
    m_pVLayout->addLayout(m_pGridLayout);
    m_pVLayout->setSpacing(0);
    m_pVLayout->setContentsMargins(40, 0, 40, 0);


    m_pMainLayout = new QVBoxLayout();
    m_pMainLayout->addWidget(m_pTitleBar);
    m_pMainLayout->addLayout(m_pVLayout);
    m_pMainLayout->setSpacing(0);
    m_pMainLayout->addStretch(2);
    m_pMainLayout->setContentsMargins(0, 0, 0, 0);

    setLayout(m_pMainLayout);
}

void KysecSettingDlg::initConnections()
{
    connect(m_pTitleBar->getReturnBtn(), SIGNAL(clicked(bool)), this, SIGNAL(signal_returnBtnClicked()));
    connect(m_pTitleBar->getMinimizeBtn(), SIGNAL(clicked(bool)), this, SIGNAL(signal_minimizeBtnClicked()));
    connect(m_pTitleBar->getCloseBtn(), SIGNAL(clicked(bool)), this, SIGNAL(signal_closeBtnClicked()));
    connect(m_pModeComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(slot_comboBoxCurrentIndexChanged(int)));
    connect(m_pExecCtrl->getSwitchBtn(), SIGNAL(checkedChanged(bool)), this, SLOT(slot_execCtrlStateChanged(bool)));
    connect(m_pFileProtect->getSwitchBtn(), SIGNAL(checkedChanged(bool)), this, SLOT(slot_fileProtectStateChanged(bool)));
    connect(m_pKModProtect->getSwitchBtn(), SIGNAL(checkedChanged(bool)), this, SLOT(slot_kmodProtectlStateChanged(bool)));
}

void KysecSettingDlg::slot_showDialog()
{    
    int status = kysec_getstatus();
    if (status == KYSEC_STATUS_NORMAL)
    {
        m_pModeComboBox->blockSignals(true);
        m_pModeComboBox->setCurrentIndex(0);
//        m_pModeComboBox->setProperty("ModeComboBox", "Normal");
        m_pModeComboBox->blockSignals(false);
        m_pModeComboBox->setEnabled(g_bAdmPrivilege);
    }

    if (status == KYSEC_STATUS_SOFTMODE)
    {
        m_pModeComboBox->blockSignals(true);
        m_pModeComboBox->setCurrentIndex(2);
//        m_pModeComboBox->setProperty("ModeComboBox", "SoftMode");
        m_pModeComboBox->blockSignals(false);
        m_pModeComboBox->setEnabled(g_bAdmPrivilege);
    }

    status = kysec_get_func_status(FUNC_EXECTL);
    m_pExecCtrl->getSwitchBtn()->setCheckedNotEmit((bool)status);
    m_pExecCtrl->set_switchbtn_enabled(g_bAdmPrivilege);    

    status = kysec_get_func_status(FUNC_FPRO);
    m_pFileProtect->getSwitchBtn()->setCheckedNotEmit((bool)status);
    m_pFileProtect->set_switchbtn_enabled(g_bAdmPrivilege);    

    status = kysec_get_func_status(FUNC_KMOD);
    m_pKModProtect->getSwitchBtn()->setCheckedNotEmit((bool)status);
    m_pKModProtect->set_switchbtn_enabled(g_bAdmPrivilege);

    setVisible(true);
}

void KysecSettingDlg::slot_comboBoxCurrentIndexChanged(int index)
{
    int cur_status = kysec_getstatus();
    int cur_index = 0;
    if (cur_status == KYSEC_STATUS_NORMAL)
        cur_index = 0;
    else
        cur_index = 2;

    int change_status = KYSEC_STATUS_NORMAL;
    if (index == 0)
        change_status = KYSEC_STATUS_NORMAL;
    else
        change_status = KYSEC_STATUS_SOFTMODE;

    int ret = kysec_setstatus(change_status);
    if (ret != 0)
    {
        m_pModeComboBox->blockSignals(true);
        m_pModeComboBox->setCurrentIndex(cur_index);
//        m_pModeComboBox->setProperty("ModeComboBox", "SoftMode");
        m_pModeComboBox->blockSignals(false);
        KysecMessageBox* msgBox = new KysecMessageBox(this);
        if (ret == 3)
            msgBox->showMsg(Msg_Warning, QString("KYSEC安全机制未启用，运行模式切换失败!"));
        else if (ret == 1)
            msgBox->showMsg(Msg_Warning, QString("当前用户无权限进行此操作，运行模式切换失败!"));
        else
        {
            if (index == 0)
                msgBox->showMsg(Msg_Warning, QString("启用KYSEC强制模式失败!"));
            else
                msgBox->showMsg(Msg_Warning, QString("启用KYSEC记录模式失败!"));
        }

        return;
    }


#if 0
    if (index == 0)
    {
        int ret = kysec_setstatus(KYSEC_STATUS_NORMAL);
        if (ret != 0)
        {
            m_pModeComboBox->blockSignals(true);
            m_pModeComboBox->setCurrentIndex(1);
//            m_pModeComboBox->setProperty("ModeComboBox", "SoftMode");
            m_pModeComboBox->blockSignals(false);
            KysecMessageBox* msgBox = new KysecMessageBox(this);
            if (ret == 3)
                msgBox->showMsg(Msg_Warning, QString("KYSEC安全机制未启用，安全模式切换失败!"));
            else if (ret == 1)
                msgBox->showMsg(Msg_Warning, QString("当前用户无权限进行此操作，设安全模式切换失败!"));
            else
                msgBox->showMsg(Msg_Warning, QString("启用KYSEC强制模式失败!"));
            return;
        }
    }

    if (index == 1)
    {
        int ret = kysec_setstatus(KYSEC_STATUS_WARNING);
        if (ret != 0)
        {
            m_pModeComboBox->blockSignals(true);
            m_pModeComboBox->setCurrentIndex(1);
//            m_pModeComboBox->setProperty("ModeComboBox", "Warning");
            m_pModeComboBox->blockSignals(false);
            KysecMessageBox* msgBox = new KysecMessageBox(this);
            if (ret == 3)
                msgBox->showMsg(Msg_Warning, QString("KYSEC安全机制未启用，安全模式切换失败!"));
            else if (ret == 1)
                msgBox->showMsg(Msg_Warning, QString("当前用户无权限进行此操作，设安全模式切换失败!"));
            else
                msgBox->showMsg(Msg_Warning, QString("启用KYSEC警告模式失败!"));
            return;
        }
    }

    if (index == 2)
    {
        int ret = kysec_setstatus(KYSEC_STATUS_SOFTMODE);
        if (ret != 0)
        {
            m_pModeComboBox->blockSignals(true);
            m_pModeComboBox->setCurrentIndex(0);
//            m_pModeComboBox->setProperty("ModeComboBox", "Normal");
            m_pModeComboBox->blockSignals(false);
            KysecMessageBox* msgBox = new KysecMessageBox(this);
            if (ret == 3)
                msgBox->showMsg(Msg_Warning, QString("KYSEC安全机制未启用，运行模式切换失败!"));
            else if (ret == 1)
                msgBox->showMsg(Msg_Warning, QString("当前用户无权限进行此操作，运行模式切换失败!"));
            else
                msgBox->showMsg(Msg_Warning, QString("启用KYSEC记录模式失败!"));
            return;
        }
    }
#endif
}

void KysecSettingDlg::slot_execCtrlStateChanged(bool checked)
{
    int ret = kysec_set_func_status(FUNC_EXECTL, (int)checked);
    if (ret != 0)
    {
        m_pExecCtrl->getSwitchBtn()->setCheckedNotEmit(!checked);
        KysecMessageBox* msgBox = new KysecMessageBox(this);
        if (checked)
            if (ret == 3)
                msgBox->showMsg(Msg_Warning, QString("KYSEC安全机制未启用，无法启用执行控制功能！"));
            else if (ret == 1)
                msgBox->showMsg(Msg_Warning, QString("当前用户无权限进行此操作！"));
            else
                msgBox->showMsg(Msg_Warning, QString("启用执行控制功能失败!"));
        else
            if (ret == 3)
                msgBox->showMsg(Msg_Warning, QString("KYSEC安全机制未启用，无法关闭执行控制功能！"));
            else if (ret == 1)
                msgBox->showMsg(Msg_Warning, QString("当前用户无权限进行此操作!"));
            else
                msgBox->showMsg(Msg_Warning, QString("关闭执行控制功能失败!"));
        return;
    }
}

void KysecSettingDlg::slot_fileProtectStateChanged(bool checked)
{
    int ret = kysec_set_func_status(FUNC_FPRO, (int)checked);
    if (ret != 0)
    {
        m_pFileProtect->getSwitchBtn()->setCheckedNotEmit(!checked);
        KysecMessageBox* msgBox = new KysecMessageBox(this);
        if (checked)            
            if (ret == 3)
                msgBox->showMsg(Msg_Warning, QString("KYSEC安全机制未启用，无法启用文件保护功能！"));
            else if (ret == 1)
                msgBox->showMsg(Msg_Warning, QString("当前用户无权限进行此操作！"));
            else
                msgBox->showMsg(Msg_Warning, QString("启用文件保护功能失败!"));
        else
            if (ret == 3)
                msgBox->showMsg(Msg_Warning, QString("KYSEC安全机制未启用，无法关闭文件保护功能！"));
            else if (ret == 1)
                msgBox->showMsg(Msg_Warning, QString("当前用户无权限进行此操作!"));
            else
                msgBox->showMsg(Msg_Warning, QString("关闭文件保护功能失败!"));
        return;
    }
}

void KysecSettingDlg::slot_kmodProtectlStateChanged(bool checked)
{
    int ret = kysec_set_func_status(FUNC_KMOD, (int)checked);
    if (ret != 0)
    {
        m_pKModProtect->getSwitchBtn()->setCheckedNotEmit(!checked);
        KysecMessageBox* msgBox = new KysecMessageBox(this);
        if (checked)
            if (ret == 3)
                msgBox->showMsg(Msg_Warning, QString("KYSEC安全机制未启用，无法启用内核模块保护功能！"));
            else if (ret == 1)
                msgBox->showMsg(Msg_Warning, QString("当前用户无权限进行此操作！"));
            else
                msgBox->showMsg(Msg_Warning, QString("启用内核模块保护功能失败!"));
        else
            if (ret == 3)
                msgBox->showMsg(Msg_Warning, QString("KYSEC安全机制未启用，无法关闭内核模块保护功能！"));
            else if (ret == 1)
                msgBox->showMsg(Msg_Warning, QString("当前用户无权限进行此操作!"));
            else
                msgBox->showMsg(Msg_Warning, QString("关闭内核模块保护功能失败!"));
        return;
    }
}
