#include "KysecTableModelBase.h"
#include "IconHelper.h"
#include "GlobalDef.h"

#include <QColor>
#include <QVariant>
#include <QVector>
#include <QPair>
#include <QMultiMap>

KysecTableModelBase::KysecTableModelBase(int type, QObject *parent)
    : QAbstractTableModel(parent)
{
    m_type = type;
    hover_row = -1;

    m_list.clear();
}

KysecTableModelBase::~KysecTableModelBase()
{
    for (int i = 0; i < m_list.size(); i++)
    {
        free(m_list.at(i).data.fpath);
        free(m_list.at(i).data.hash);
    }

    m_list.clear();
}

void KysecTableModelBase::getRowData(int row, db_object &obj) const
{
    if (row < 0 || row >= m_list.size())
        return;

    obj = m_list.at(row).data;
    return;
}

void KysecTableModelBase::getWhlistData(int row, whitelist_data &obj) const
{
    if (row < 0 || row >= m_list.size())
        return;

    obj = m_list.at(row);
    return;
}

void KysecTableModelBase::refreshData(const char *key)
{
    struct object_list list;
    struct object_entry* item;
    int res = kysec_whlist_load(m_type, key, &list);
    if (res != 0)
    {
        kysec_whlist_objects_free(&list);
        return;
    }

    clearList();
    SLIST_FOREACH(item, &list, entries)
    {
        if (!m_typeFilters.contains(item->object.type) || !m_typeFilters.value(item->object.type))
            continue;

        if (m_type != kysec_filepro)
        {
//            if (!m_statusFilters.contains(item->object.exectl) || !m_statusFilters.value(item->object.exectl))
//                continue;
            int exectl_status_type = get_exectl_status_type(item->object.exectl, item->object.status);
            if (!m_statusFilters.value(exectl_status_type))
                continue;
        }
        else
        {
            if (!m_statusFilters.contains(item->object.filepro) || !m_statusFilters.value(item->object.filepro))
                continue;
        }

        whitelist_data temp;
        temp.data.fpath = strdup(item->object.fpath);
        temp.data.hash = strdup(item->object.hash);
        temp.data.exectl = item->object.exectl;
        temp.data.filepro = item->object.filepro;
        temp.data.rmmodpro = item->object.rmmodpro;
        temp.data.type = item->object.type;
        temp.data.status = item->object.status;
        temp.checked = false;

        m_list.push_back(temp);

    }
    kysec_whlist_objects_free(&list);

    beginResetModel();
    endResetModel();

    emit signal_checkedChanged(0);
    emit signal_checkedStateChanged(0);
}

int KysecTableModelBase::deleteObjects()
{
    char **list = NULL;

    int count = 0;
    foreach (whitelist_data temp, m_list)
    {
        if (temp.checked)
            count++;
    }

    list = (char **)malloc(count * sizeof(char *));
    int index = 0;
    for (int i = 0; i < m_list.size(); i++)
    {
        if (m_list.at(i).checked)
        {
            list[index] = strdup(m_list.at(i).data.fpath);
            index++;
            if (index >= count)
                break;
        }
    }

    int ret = kysec_whlist_dels(m_type, list, count);
    for (int i = 0; i < count; i++)
    {
        free(list[i]);
    }
    free(list);

    refreshData();
    return ret;
}

int KysecTableModelBase::updateObjects()
{
    char **list = NULL;

    int count = 0;
    foreach (whitelist_data temp, m_list)
    {
        if (temp.checked)
            count++;
    }

    list = (char **)malloc(count * sizeof(char *));
    int index = 0;
    for (int i = 0; i < m_list.size(); i++)
    {
        if (m_list.at(i).checked)
        {
            list[index] = strdup(m_list.at(i).data.fpath);
            index++;
            if (index >= count)
                break;
        }
    }

    int ret = kysec_whlist_updates(m_type, list, count);
    for (int i = 0; i < count; i++)
    {
        free(list[i]);
    }
    free(list);

    refreshData();
    return ret;
}

int KysecTableModelBase::updateKoStatus(int row)
{
    db_object obj = m_list.at(row).data;
//    if (obj.exectl == exectl_sign_unknown || obj.status != 0)
//    {
//        emit signal_updateKoStatusFailed(0);
//        return -1;
//    }

    int status = m_list[row].data.rmmodpro == 0 ? 1 : 0;

    char **list = NULL;

    list = (char **)malloc(1 * sizeof(char *));
    list[0] = strdup(m_list.at(row).data.fpath);

    int ret = kysec_whlist_update_rmmodpros(status, list, 1);
    if (ret == 0)
    {
        m_list[row].data.rmmodpro = status;
        ret = 0;
    }
    else
    {        
        emit signal_updateKoStatusFailed(1);
        ret = -1;
    }

    free(list[0]);
    free(list);

    beginResetModel();
    endResetModel();
    return ret;
}

int KysecTableModelBase::getCheckedCount() const
{
    int count = 0;
    for (int i = 0; i < m_list.size(); i++)
    {
        if (m_list.at(i).checked)
            count++;
    }

    return count;
}

QStringList KysecTableModelBase::getCheckedList()
{
    QStringList list;
    for (int i = 0; i < m_list.size(); i++)
    {
        if (m_list.at(i).checked)
            list.push_back(QString(m_list.at(i).data.fpath));
    }

    return list;
}

void KysecTableModelBase::updateChecked(int row)
{
    bool status = m_list[row].checked ? false : true;
    m_list[row].checked = status;

    int checkCount = 0;
    for (int i = 0; i < m_list.size(); i++)
    {
        if (m_list.at(i).checked)
            checkCount++;
    }
    emit signal_checkedChanged(checkCount);
    if (checkCount == 0)
        emit signal_checkedStateChanged(0);
    else if (checkCount == m_list.size())
        emit signal_checkedStateChanged(2);
    else
        emit signal_checkedStateChanged(1);

    beginResetModel();
    endResetModel();
    return ;
}

void KysecTableModelBase::setHoverRow(int row)
{
    hover_row = row;
    //reset();
}

void KysecTableModelBase::setTypeFilters(QMap<int, bool> typeFilters)
{
    m_typeFilters = typeFilters;
}

void KysecTableModelBase::getTypeFilters(QMap<int, bool> &typeFilters)
{
    typeFilters = m_typeFilters;
}

void KysecTableModelBase::setStatusFilters(QMap<int, bool> statusFilters)
{
    m_statusFilters = statusFilters;
}

void KysecTableModelBase::getStatusFilters(QMap<int, bool> &statusFilters)
{
    statusFilters = m_statusFilters;
}

void KysecTableModelBase::getStatisticsData(int &sum, int &distort)
{
    sum = m_list.size();
    distort = 0;
    for (int i = 0; i < m_list.size(); i++)
    {
        if (m_list.at(i).data.status == 1)
            distort++;
//        if (m_type != kysec_filepro && m_list.at(i).data.exectl == exectl_sign_unknown)
//                distort++;

//        if (m_type == kysec_filepro && m_list.at(i).data.filepro == filepro_sign_none)
//                distort++;
    }
}

void KysecTableModelBase::slot_checkedStateChanged(int state)
{
    for (int i = 0; i < m_list.size(); i++)
    {
        m_list[i].checked = (state == Qt::Checked);
    }

    if (state == Qt::Checked)
        emit signal_checkedChanged(m_list.size());
    else
        emit signal_checkedChanged(0);
    beginResetModel();
    endResetModel();
}

QVariant KysecTableModelBase::data(const QModelIndex &index, int role) const
{
//    if (!index.isValid())
//        return QVariant();

//    int row = index.row();  //行号
//    int col = index.column();
//    if (row < 0 || row >= m_list.size())
//        return QVariant();

//    switch (role)
//    {
//    case Qt::BackgroundColorRole:
//    {
//        if (row == hover_row && g_bAdmPrivilege) {
//            return QColor("#E9EBEE");
//        }
//    }
//    case Qt::FontRole:
//    {
//        if (col == 0)
//            return IconHelper::Instance()->getFont(12);
//        else
//        {
//            QFont ft;
//            ft.setPixelSize(12);
//            return ft;
//        }
//    }
//    case Qt::DecorationRole:
//    {  //图标
//        //...
//    }
//    default:
//        return QVariant();
//    }

    return QVariant();
}

void KysecTableModelBase::sort(int column, Qt::SortOrder order)
{
    if (column == 0)
        return;

    QMultiMap<QString, int> map;
    for (int row = 0; row < rowCount(); ++row)
    {
        QModelIndex index = this->index(row,column);
        map.insert(index.data().toString(), index.row());
    }

    QList<whitelist_data>  sort_data;
    QMultiMap<QString, int>::iterator iter; //遍历map
    for ( iter = map.begin(); iter != map.end(); ++iter )
    {
        sort_data.append(m_list.at(iter.value()));
    }

    if (Qt::AscendingOrder == order)
        m_list=sort_data;
    else
    {
        m_list.clear();
        for (int i = sort_data.size() - 1; i >= 0; i--)
        {
            m_list.push_back(sort_data.at(i));
        }
    }

    beginResetModel();
    endResetModel();
}

void KysecTableModelBase::clearList()
{
    for (int i = 0; i < m_list.size(); i++)
    {
        free(m_list.at(i).data.fpath);
        free(m_list.at(i).data.hash);
    }

    m_list.clear();
}
