#include "ProcessAddWaitingDialog.h"
#include <QFileInfo>
#include <QDirIterator>

#include "unistd.h"
#include <kysecwhlist/kysec_whlist.h>
#include <kysecwhlist/kysec_file_type.h>

ProcessAddWaitingDialog::ProcessAddWaitingDialog(QWidget *parent) : WaitingDialogBase(0, parent)
{

}

ProcessAddWaitingDialog::~ProcessAddWaitingDialog()
{

}

void ProcessAddWaitingDialog::setPathList(int type, QStringList list)
{
    m_type = type;
    m_list = list;
}

int ProcessAddWaitingDialog::processEvent()
{
    QStringList file_list = extractFileList();

    char **list = NULL;
    int count = file_list.size();
    if (count == 0)
    {
        setResult(-99);
        set_error_msg(QString("未发现符合要求文件,请重新选择添加!"));
        return 0;
    }

    list = (char **)malloc(count * sizeof(char *));
    for (int i = 0; i < file_list.size(); i++)
    {
        list[i] = strdup(file_list.at(i).toLocal8Bit().data());
    }

    int ret = kysec_whlist_adds(m_type, list, count);
    if (ret != 0)
    {
        QString dbus_err = QString(kysec_whlist_last_err());
        QString err;
        switch (ret) {
        case 1:
        case 2:
            err = QString("授权认证失败,禁止添加!");
            break;
        case 3:
            err = QString("KYSEC安全机制未启用,禁止添加!");
            break;
        case 4:
            err = QString("数据库异常,添加白名单记录失败!");
            break;
        case 5:
            err = QString("%1 :获取文件标记失败!").arg(dbus_err.split(":").at(0));
            break;
        case 6:
            err = QString("%1 :设置文件标记失败!").arg(dbus_err.split(":").at(0));
            break;
        case 7:
            err = QString("无效参数，添加白名单记录失败!").arg(dbus_err.split(":").at(0));
            break;
        case 8:
            err = QString("%1 :获取待添加文件列表失败!").arg(dbus_err.split(":").at(0));
            break;
        case 9:
            err = QString("%1 :文件属性异常!").arg(dbus_err.split(":").at(0));
            break;
        default:
            err = QString("未知错误,添加白名单失败!");
            break;
        }

        set_error_msg(err);
    }
    for (int i = 0; i < count; i++)
    {
        free(list[i]);
    }
    free(list);

    setResult(ret);
    return 0;
}

QStringList ProcessAddWaitingDialog::extractFileList()
{
    QStringList list;
    foreach (QString path, m_list)
    {
        QFileInfo info(path);
        if (info.isDir())
        {
            QDirIterator iter(path, QDirIterator::Subdirectories);
            while (iter.hasNext())
            {
                iter.next();
                QFileInfo _info = iter.fileInfo();
                if (_info.isDir())
                    continue;

                if (isFileValid(_info.absoluteFilePath()))
                    list.push_back(_info.absoluteFilePath());
            }
        }
        else
        {
            if (isFileValid(path))
                list.push_back(path);
        }
    }

    return list;
}

bool ProcessAddWaitingDialog::isFileValid(QString path)
{
    int file_type = parse_file_type(path.toLocal8Bit().data());

    if (m_type == 0)
    {
        if (file_type == object_program || file_type == object_script || file_type == object_library)
            return true;
        else
            return false;
    }
    else if (m_type ==1)
    {
        return true;
    }
    else if (m_type == 2)
    {
        if (file_type == object_kmodule)
            return true;
        else
            return false;
    }
    else
        return false;
}
