#include "TitleBar.h"
#include <QtWidgets/QLabel>
#include <QPaintEvent>
#include <QPainter>
#include <QtWidgets/QSpacerItem>
#include "IconHelper.h"
#include "Common.h"


TitleBar::TitleBar(QWidget *parent) :
    QWidget(parent)
{    
    WidgetLayoutInit();
}

TitleBar::~TitleBar()
{
    delete m_pCloseBtn;
    delete m_pMinimizeBtn;
    delete m_pMenuBtn;

    delete m_pToolhlayout;
}

void TitleBar::setLogoIcon(QString icon)
{
    QPixmap pix(icon);
    m_pLogo->setPixmap(pix);
}

void TitleBar::setCloseIcon(QString icon)
{
    m_pCloseBtn->setIcon(QIcon(icon));
}

void TitleBar::hideLogo()
{
    m_pLogo->setVisible(false);
    m_pLabel->setVisible(false);
}

void TitleBar::setLogoLabel(QString text, int size, QString color)
{
    m_pLabel->setText(text);

    if (size != 0)
    {
        QFont font;
        font.setPixelSize(size);
        m_pLabel->setFont(font);
    }
    if (!color.isEmpty())
    {
        QPalette palette = this->palette();
        palette.setColor(QPalette::WindowText, QColor(color));
        m_pLabel->setPalette(palette);
    }
}

void TitleBar::setBackgroundColor(QString color)
{
    QPalette palette(this->palette());
    palette.setColor(QPalette::Background, QColor(color));
    this->setPalette(palette);
}

void TitleBar::InsertUserLayout(QLayout *UserLayout, int pos, int stretch)
{
    if (NULL != m_pToolhlayout)
        m_pToolhlayout->insertLayout(pos, UserLayout, stretch);
}

void TitleBar::InsertUserWidget(QWidget *widget, int index, int stretch, Qt::Alignment alignment)
{
    if (NULL != m_pToolhlayout)
        m_pToolhlayout->insertWidget(index, widget, stretch, alignment);
}

void TitleBar::WidgetLayoutInit()
{
    this->resize(TITLEBAR_WIDTH, TITLEBAR_HEIGHT);
    this->setFixedHeight(TITLEBAR_HEIGHT);

    setAutoFillBackground(true);
    QPalette palette(this->palette());
    palette.setColor(QPalette::Background, QColor("#E4E7EA"));
    this->setPalette(palette);

    m_pLogo = new QLabel(this);
    QPixmap pix(":/images/logo/kysec_logo/24.png");
    m_pLogo->setPixmap(pix);
    m_pLogo->setFixedSize(LOGO_24_WIDTH, LOGO_24_HEIGHT);

    QFont ft;

    m_pLabel = new QLabel(this);
    palette.setColor(QPalette::WindowText, QColor("#1D1D1F"));
    ft.setPixelSize(16);
    m_pLabel->setFont(ft);
    m_pLabel->setPalette(palette);
    m_pLabel->setScaledContents(true);

    m_pCloseBtn = new QPushButton(this);
    m_pCloseBtn->setFixedSize(MENU_BTN_WIDTH, MENU_BTN_HEIGHT);
    m_pCloseBtn->setObjectName("MenuBtn");
    m_pCloseBtn->setToolTip(QString("关闭"));
    m_pCloseBtn->setIcon(QIcon(":/images/image/close_icon.png"));

    m_pMinimizeBtn = new QPushButton(this);
    m_pMinimizeBtn->setFixedSize(MENU_BTN_WIDTH, MENU_BTN_HEIGHT);
    m_pMinimizeBtn->setObjectName("MenuBtn");
    m_pMinimizeBtn->setToolTip(QString("最小化"));
    m_pMinimizeBtn->setIcon(QIcon(":/images/image/minimun_icon.png"));

    m_pMenuBtn = new QPushButton(this);
    m_pMenuBtn->setFixedSize(MENU_BTN_WIDTH, MENU_BTN_HEIGHT);
    m_pMenuBtn->setObjectName("MenuBtn");
    m_pMenuBtn->setToolTip(QString("菜单"));
    m_pMenuBtn->setIcon(QIcon(":/images/image/menu_icon.png"));

    m_pReturnBtn = new QPushButton(this);
    m_pReturnBtn->setFixedSize(MENU_BTN_WIDTH, MENU_BTN_HEIGHT);
    m_pReturnBtn->setObjectName("MenuBtn");
    m_pReturnBtn->setToolTip(QString("返回"));
    m_pReturnBtn->setIcon(QIcon(":/images/image/return.png"));

    m_pToolhlayout  = new QHBoxLayout;
    m_pToolhlayout->setSpacing(8);
    m_pToolhlayout->addWidget(m_pLogo, 0);
    m_pToolhlayout->addWidget(m_pLabel, 0);
    m_pToolhlayout->addSpacerItem(new QSpacerItem(800,24, QSizePolicy::Expanding));    
    m_pToolhlayout->addWidget(m_pMenuBtn, 0);
    m_pToolhlayout->addWidget(m_pReturnBtn, 0);
    m_pToolhlayout->addWidget(m_pMinimizeBtn, 0);
    m_pToolhlayout->addWidget(m_pCloseBtn, 0);
    m_pToolhlayout->setSpacing(8);
    m_pToolhlayout->setContentsMargins(20, 0, 8, 0);

    setLayout(m_pToolhlayout);
}
