/*************************************************************************
 * 功能:  等待界面
 * 效果： 界面有进度条来回滚动显示
 * 原理： 耗时事务放到子线程处理，界面不卡死
 * 注意： 1.本类会启动一个独立的工作线程，线程执行函数为processEvent()函数
 *       2.子线程不能操作UI的任何资源；
 *       3.本类不能单独使用，子类需要继承GUIWaitingDialogBase类，并覆盖processEvent()函数
 *       4.调用start()函数后，不要再调用exec()函数或show()函数
 ************************************************************************/
#ifndef WAITINGDIALOGBASE_H
#define WAITINGDIALOGBASE_H


#include <QtWidgets/QDialog>
#include <QThread>
#include <QTimer>
#include <QtWidgets/QPushButton>

#include "TitleBar.h"
#include "FlatDropWidget.h"

class QLabel;
class QMovie;
class QPropertyAnimation;
class QProgressBar;
class CProcessEventThread;

class WaitingDialogBase : public FlatDropWidget
{
    Q_OBJECT
public:
    explicit WaitingDialogBase(int operate, QWidget *parent = 0);
    virtual ~WaitingDialogBase();

    void setText(QString title, QString text);
	void setTimerInterval(int msec);
	void setIsCanForceClose(bool isCanForceClose);
    bool isForceColse() { return m_bForceColse; }
	int  result() { return m_result; }
    QString error_msg()    {   return m_error_msg; }

    void start();
	int exec(){return 0;}//屏蔽该函数

    friend class CProcessEventThread;
protected:
    virtual int processEvent();
    void setResult(int result)  {   m_result = result;  }
    void set_error_msg(QString error_msg)  {   m_error_msg = error_msg;  }

protected:
    void closeEvent(QCloseEvent *event);

public slots:
	void slSetResult(int res);
private slots:
    void slClose();
    void slAnimationFinished();
	void slTimerTimeout();

    void slot_BtnClicked();

private:
    void initUI();

private:
    QString m_error_msg;
    int m_operate;              //0, 添加； 1，更新； 2，删除

	int m_result;				// 执行结果：-1，未知；0，正常结束，即子线程通过slClose()槽函数关闭；1，强制关闭本窗体，即通过窗口的"X"按键关闭；2，等待超时
	QTimer *m_pTimer;
	int m_timerInterval;		// 定时器超时时间，为0表示永不超时    
    bool m_bForceColse;         // 是否强制关闭本窗体F:外部通过slClose()槽函数关闭,T:通过窗口的"X"按键关闭
	bool m_bIsCanForceClose;    // 是否允许强制关闭本窗体
    bool m_bIsNeedStopAnimation;// 是否需要停止动画	
    QPropertyAnimation *m_pAnimation;
    CProcessEventThread *m_pProcessEventThread;

    TitleBar* m_pTitleBar;
    QLabel *m_pLabel;
    QProgressBar *m_pProgressBar;    
    QVBoxLayout* m_pMainLayout;
};

class CProcessEventThread : public QThread
{
    Q_OBJECT
public:
    explicit CProcessEventThread(WaitingDialogBase *pWaitingDialog);
    virtual ~CProcessEventThread();

signals:
    void sigCompleted();//事务处理完成后发此信号

protected:
    virtual void run();

private:
    WaitingDialogBase *m_pWaitingDialog;
};


#endif // WAITINGDIALOGBASE_H
