#include <QtSingleApplication>
#include <QTextCodec>
#include <QFile>
#include <QString>
#include <getopt.h>
#include <QDebug>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include "GlobalHelper.h"
#include "IconHelper.h"
#include "GlobalDef.h"

#include "KysecManage.h"
#include "KysecMessageBox.h"
#include "ProcessAddWaitingDialog.h"

#include "kysec/status.h"
#include "kysec/libkyuser.h"


int open_3adm()
{
    if (kysec_get_3adm_status() == FUNC_ENABLED) {
        if (is_secadm())
            return 1;
        else {
            qDebug() << "kysec-ui: 3adm is enable, but uid is not secadm" << endl;
            return -1;
        }
    }
    return 0;
}

void initGlobalVar()
{
    g_mapFileType.clear();
    g_mapFileType.insert(object_program, QString("可执行程序"));
    g_mapFileType.insert(object_library, QString("共享库"));
    g_mapFileType.insert(object_script, QString("可执行脚本"));
    g_mapFileType.insert(object_kmodule, QString("内核模块"));
    g_mapFileType.insert(object_other, QString("其他文件"));

    g_mapExectlSatus.clear();
    g_mapExectlSatus.insert(exectl_status_verified, QString("已认证"));
    g_mapExectlSatus.insert(exectl_status_system, QString("系统认证"));
    g_mapExectlSatus.insert(exectl_status_unauth, QString("未认证"));
    g_mapExectlSatus.insert(exectl_status_distort, QString("被篡改"));

    g_mapFileProtectStatus.clear();
    g_mapFileProtectStatus.insert(filepro_sign_readonly, QString("受保护"));
    g_mapFileProtectStatus.insert(filepro_sign_none, QString("被篡改"));

    g_bAdmPrivilege = check_user_privilege();
}

int main(int argc, char *argv[])
{
    QtSingleApplication a(QString("kysec-ui"), argc, argv);

    if (a.isRunning())
        return 0;

    int opt = 0;
    int option_index = 0;
    char *caller = NULL;
    static struct option long_options[] = {
        {"caller", required_argument, NULL, 'c'},
        {0,	 0, 0, 0}
    };

    while ((opt = getopt_long(argc, argv, "h", long_options, &option_index)) != -1 ) {
        switch (opt) {
        case 'c':
            caller = optarg;
            break;
        default:
            break;
        }
    }

    GlobalHelper::SetUTF8Code();
    GlobalHelper::SetStyle("blue.css");//蓝色风格
    GlobalHelper::SetChinese();

    if (kysec_getstatus() == KYSEC_STATUS_DISABLED)
    {
        KysecMessageBox* msgBox = new KysecMessageBox();
        GlobalHelper::FormInCenter(msgBox);
        msgBox->showMsg(Msg_Information, QString("KYSEC安全机制已禁用，请先启用KYSEC安全机制!"));
        return 0;
    }

    initGlobalVar();

#if 0   //不再控制用户启动程序，功能控制下沉至dbus服务
    int ret = open_3adm();
    if (ret < 0)
    {
        KysecMessageBox* msgBox = new KysecMessageBox();
        GlobalHelper::FormInCenter(msgBox);
        msgBox->showMsg(Msg_Information, QString("三权分立模式已启动,请使用安全管理员账号启动!"));
        return 0;
    }
#endif
    KysecManage w;
    if ((NULL != caller) && (0 == strcmp(caller, "ksc-defender")))
    {
        w.enter_cfg_dialog();
    }
    w.show();


    return a.exec();
}
